@@ -762,3 +762,90 @@ while (dlist != NULL)
 
 return window_new;
 }
+
+/*************** external function ***********
+ *                                           *
+ *           GAMGI_ENGINE_COPY_OBJECT        *
+ *                                           *
+ *********************************************/
+
+gamgi_object *gamgi_engine_copy_object (gamgi_object *object)
+{
+gamgi_object *object_new;
+
+switch (object->class)
+  {
+  case GAMGI_ENGINE_TEXT:
+  object_new = GAMGI_CAST_OBJECT gamgi_engine_copy_text (GAMGI_CAST_TEXT object);
+  break;
+
+  case GAMGI_ENGINE_ORBITAL:
+  object_new = GAMGI_CAST_OBJECT gamgi_engine_copy_orbital (GAMGI_CAST_ORBITAL object);
+  break;
+
+  case GAMGI_ENGINE_BOND:
+  object_new = GAMGI_CAST_OBJECT gamgi_engine_copy_bond (GAMGI_CAST_BOND object);
+  break;
+
+  case GAMGI_ENGINE_ATOM:
+  object_new = GAMGI_CAST_OBJECT gamgi_engine_copy_atom (GAMGI_CAST_ATOM object);
+  break;
+
+  case GAMGI_ENGINE_DIRECTION:
+  object_new = GAMGI_CAST_OBJECT gamgi_engine_copy_direction (GAMGI_CAST_DIRECTION object);
+  break;
+
+  case GAMGI_ENGINE_PLANE:
+  object_new = GAMGI_CAST_OBJECT gamgi_engine_copy_plane (GAMGI_CAST_PLANE object);
+  break;
+
+  case GAMGI_ENGINE_GROUP:
+  object_new = GAMGI_CAST_OBJECT gamgi_engine_copy_group (GAMGI_CAST_GROUP object);
+  break;
+
+  case GAMGI_ENGINE_MOLECULE:
+  object_new = GAMGI_CAST_OBJECT gamgi_engine_copy_molecule (GAMGI_CAST_MOLECULE object);
+  break;
+
+  case GAMGI_ENGINE_CLUSTER:
+  object_new = GAMGI_CAST_OBJECT gamgi_engine_copy_cluster (GAMGI_CAST_CLUSTER object);
+  break;
+
+  case GAMGI_ENGINE_CELL:
+  object_new = GAMGI_CAST_OBJECT gamgi_engine_copy_cell (GAMGI_CAST_CELL object);
+  break;
+
+  case GAMGI_ENGINE_ARROW:
+  object_new = GAMGI_CAST_OBJECT gamgi_engine_copy_arrow (GAMGI_CAST_ARROW object);
+  break;
+
+  case GAMGI_ENGINE_SHAPE:
+  object_new = GAMGI_CAST_OBJECT gamgi_engine_copy_shape (GAMGI_CAST_SHAPE object);
+  break;
+
+  case GAMGI_ENGINE_GRAPH:
+  object_new = GAMGI_CAST_OBJECT gamgi_engine_copy_graph (GAMGI_CAST_GRAPH object);
+  break;
+
+  case GAMGI_ENGINE_ASSEMBLY:
+  object_new = GAMGI_CAST_OBJECT gamgi_engine_copy_assembly (GAMGI_CAST_ASSEMBLY object);
+  break;
+
+  case GAMGI_ENGINE_LIGHT:
+  object_new = GAMGI_CAST_OBJECT gamgi_engine_copy_light (GAMGI_CAST_LIGHT object);
+  break;
+
+  case GAMGI_ENGINE_LAYER:
+  object_new = GAMGI_CAST_OBJECT gamgi_engine_copy_layer (GAMGI_CAST_LAYER object);
+  break;
+
+  case GAMGI_ENGINE_WINDOW:
+  object_new = GAMGI_CAST_OBJECT gamgi_engine_copy_window (GAMGI_CAST_WINDOW object);
+  break;
+
+  default:
+  object_new = NULL;
+  }
+
+return object_new;
+}
