@@ -2051,7 +2051,7 @@ int depth_last = GAMGI_EXPAT_DEPTH_MIN;
  * write gml header *
  ********************/
 
-if (GAMGI_EXPAT_HEADER == TRUE) static_header_gml (fp, error);
+if (GAMGI_EXPAT_HEADER_GML == TRUE) static_header_gml (fp, error);
 
 /***********************
  * start gml root node *
@@ -2087,7 +2087,7 @@ int depth = 0;
  * write X3D header *
  ********************/
 
-static_header_x3d (fp, error);
+if (GAMGI_EXPAT_HEADER_X3D == TRUE) static_header_x3d (fp, error);
 
 /***********************
  * start X3D root node *
