@@ -665,17 +665,17 @@ if (direction->reference == GAMGI_ENGINE_CELL)
 
   if (direction->node[3] != FALSE)
     {
-    if (direction->node[3] == GAMGI_PHYS_NODE_110)
+    if (direction->node[3] == GAMGI_PHYS_110)
       sprintf (string, "o4=\"110\"");
-    if (direction->node[3] == GAMGI_PHYS_NODE_101)
+    if (direction->node[3] == GAMGI_PHYS_101)
       sprintf (string, "o4=\"101\"");
-    if (direction->node[3] == GAMGI_PHYS_NODE_011)
+    if (direction->node[3] == GAMGI_PHYS_011)
       sprintf (string, "o4=\"011\"");
-    if (direction->node[3] == GAMGI_PHYS_NODE_111)
+    if (direction->node[3] == GAMGI_PHYS_111)
       sprintf (string, "o4=\"111\"");
-    if (direction->node[3] == GAMGI_PHYS_NODE_211)
+    if (direction->node[3] == GAMGI_PHYS_211)
       sprintf (string, "o4=\"211\"");
-    if (direction->node[3] == GAMGI_PHYS_NODE_122)
+    if (direction->node[3] == GAMGI_PHYS_122)
       sprintf (string, "o4=\"122\"");
     gamgi_expat_export_attribute (fp, string, depth, column, error);
     }
@@ -1332,12 +1332,12 @@ if (o1 != 0 || o2 != 0 || o3 != 0)
 
 if (o4 != FALSE)
   {
-  if (o4 == GAMGI_PHYS_NODE_110) sprintf (string, "o4=\"110\"");
-  if (o4 == GAMGI_PHYS_NODE_101) sprintf (string, "o4=\"101\"");
-  if (o4 == GAMGI_PHYS_NODE_011) sprintf (string, "o4=\"011\"");
-  if (o4 == GAMGI_PHYS_NODE_111) sprintf (string, "o4=\"111\"");
-  if (o4 == GAMGI_PHYS_NODE_211) sprintf (string, "o4=\"211\"");
-  if (o4 == GAMGI_PHYS_NODE_122) sprintf (string, "o4=\"122\"");
+  if (o4 == GAMGI_PHYS_110) sprintf (string, "o4=\"110\"");
+  if (o4 == GAMGI_PHYS_101) sprintf (string, "o4=\"101\"");
+  if (o4 == GAMGI_PHYS_011) sprintf (string, "o4=\"011\"");
+  if (o4 == GAMGI_PHYS_111) sprintf (string, "o4=\"111\"");
+  if (o4 == GAMGI_PHYS_211) sprintf (string, "o4=\"211\"");
+  if (o4 == GAMGI_PHYS_122) sprintf (string, "o4=\"122\"");
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
