@@ -13,17 +13,24 @@
  * external functions *
  **********************/
 
-void gamgi_global_selection_focus (void);
-
 void gamgi_global_selection_layer (void);
 
+void gamgi_global_selection_focus (void);
+
 void gamgi_global_selection_undo (void);
 
 void gamgi_global_selection_draw (void);
 
-void gamgi_global_selection_show (char *label);
+void gamgi_global_selection_hide (char *name, gamgi_window *window);
 
-void gamgi_global_selection_hide (char *label);
+void gamgi_global_selection_show (char *name, gamgi_window *window);
+
+void gamgi_global_selection_update (gamgi_dlist **start,
+char *label, gamgi_window *window);
+
+void gamgi_global_selection_update_objects (gamgi_window *window);
+
+void gamgi_global_selection_update_windows (gamgi_dlist **start, char *label);
 
 void gamgi_global_selection_link (gamgi_dlist *start);
 
