@@ -19,7 +19,6 @@
 #include "gamgi_engine_link.h"
 #include "gamgi_engine_unlink.h"
 #include "gamgi_engine_copy.h"
-#include "gamgi_engine_remove.h"
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_gtk_object.h"
 #include "gamgi_gtk_history.h"
@@ -181,22 +180,12 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
 sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_GTK_LINK_Z);
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 
-/***********************************
- * reset hierarchy, origin buttons *
- ***********************************/
-
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
-  {
-  button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_above");
-  gtk_button_clicked (GTK_BUTTON (button));
-  }
-else
-  {
-  button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_below");
-  gtk_button_clicked (GTK_BUTTON (button));
-  }
+/***************************
+ * reset hierarchy, origin *
+ ***************************/
 
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_below");
+gtk_button_clicked (GTK_BUTTON (button));
 static_hierarchy (NULL, window);
 }
 
@@ -249,8 +238,6 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
    ****************************/
 
   gtk_widget_set_sensitive (hbox, TRUE);
-  button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_below");
-  gtk_button_clicked (GTK_BUTTON (button));
   }
 else
   {
@@ -260,8 +247,6 @@ else
 
   static_reset (window);
   gtk_widget_set_sensitive (hbox, FALSE);
-  button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_above");
-  gtk_button_clicked (GTK_BUTTON (button));
   }
 
 static_reference (NULL, window);
@@ -388,7 +373,7 @@ cache.object = gamgi_gtk_object_name_number (dialog,
 "entry_object", static_class (window), NULL);
 if (cache.object == NULL)
   {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid Object", window);
+  gamgi_gtk_dialog_message_create ("Error", "Invalid object", window);
   return FALSE;
   }
 
@@ -441,8 +426,7 @@ return TRUE;
 }
 
 static gamgi_bool static_apply (gamgi_object *child, gamgi_object *parent,
-gamgi_layer *layer_child, gamgi_layer *layer_parent, gamgi_window *window_child,
-gamgi_window *window_parent, gamgi_window *window_dialog)
+gamgi_layer *layer_child, gamgi_layer *layer_parent, gamgi_window *window)
 {
 /********************************************
  * check if child already belongs to parent *
@@ -452,7 +436,7 @@ if (child->object == parent)
   {
   if (cache.local == TRUE)
     gamgi_gtk_dialog_message_create ("Error",
-    "Child already linked to parent", window_dialog);
+    "Child already linked to parent", window);
   return FALSE;
   }
 
@@ -469,7 +453,7 @@ if (gamgi_gtk_object_independence (child) == FALSE)
   {
   if (cache.local == TRUE)
     gamgi_gtk_dialog_message_create ("Error",
-    "Child is not an independent object", window_dialog);
+    "Child is not an independent object", window);
   return FALSE;
   }
 
@@ -484,37 +468,36 @@ if (cache.local == TRUE)
     gamgi_gtk_history_update (layer_child, layer_child->undo, GAMGI_ENGINE_UNDO);
   }
 
-/************************************************************
- * When parent and child are recursive objects (assembly,   *
- * cluster, group or text), check if the parent belongs     *
- * to the child!: in that case, link first the parent to    *
- * the child parent before linking the child to the parent. *
- ************************************************************/
-
-if (child->class == parent->class &&
-gamgi_engine_find_object (parent, child) == TRUE)
+if (cache.local == FALSE && cache.above == FALSE)
   {
-  gamgi_engine_unlink_object (parent);
-  gamgi_engine_link_object_object (parent, child->object);
+  /*******************************************
+   * as child object is a new instance,      *
+   * there is no need to check for recursive *
+   * objects or to check for half bonds      *
+   *******************************************/
+
+  child = gamgi_engine_copy_object (child);
+  }
+else
+  {
+  /************************************
+   * remove all bonds that are not    *
+   * entirely inside the child object *
+   ************************************/
+
+  if (layer_parent != layer_child) gamgi_chem_bond_half_remove (child);
+
+  /***************************************************************
+   * if atom is defining an atomic plane,direction then reparent *
+   *  plane,direction child objects and remove plane,direction   *
+   ***************************************************************/
+
+  if (child->class == GAMGI_ENGINE_ATOM)
+    gamgi_chem_atom_unlink (GAMGI_CAST_ATOM child);
+  else
+    gamgi_engine_unlink_object (child);
   }
 
-/************************************
- * remove all bonds that are not    *
- * entirely inside the child object *
- ************************************/
-
-if (layer_parent != layer_child) gamgi_chem_bond_half_remove (child);
-
-/********************************************************
- * link child to parent: if atom is defining an         *
- * atomic plane,direction then reparent plane,direction *
- * child objects and remove plane,direction             *
- ********************************************************/
-
-if (child->class == GAMGI_ENGINE_ATOM)
-  gamgi_chem_atom_unlink (GAMGI_CAST_ATOM child);
-else
-  gamgi_engine_unlink_object (child);
 gamgi_engine_link_object_object (child, parent);
 
 /**************************
@@ -528,17 +511,17 @@ return TRUE;
 
 static void static_ok_global (gamgi_window *window_dialog)
 {
-gamgi_window *window_child, *window_parent;
+gamgi_window *window_parent;
 gamgi_layer *layer_child, *layer_parent;
-gamgi_object *child, *child_new, *parent;
+gamgi_object *child, *parent;
 gamgi_dlist *dlist;
 gamgi_slist *start;
 
 cache.local = FALSE;
 
-/***********************
- * get child atom list *
- ***********************/
+/*****************
+ * get atom list *
+ *****************/
 
 if (gamgi->atoms == NULL)
   { gamgi_gtk_dialog_message_create ("Error",
@@ -561,35 +544,40 @@ gamgi_global_selection_focus ();
 
 if (cache.above == TRUE)
   {
-  /*********************************
-   * link each atom of the list to *
-   * the parent selected object    *
-   *********************************/
+  /******************************
+   * link each listed atom to   *
+   * the parent selected object *
+   ******************************/
 
   parent = cache.object;
   layer_parent = gamgi_engine_find_layer (parent);
-  window_parent =  GAMGI_CAST_WINDOW layer_parent->object.object;
 
   start = NULL;
   for (dlist = gamgi->atoms; dlist != NULL; dlist = dlist->next)
     {
     child = GAMGI_CAST_OBJECT dlist->data;
     layer_child = gamgi_engine_find_layer (child);
-    window_child =  GAMGI_CAST_WINDOW layer_child->object.object;
 
-    if (static_apply (child, parent, layer_child, layer_parent,
-    window_child, window_parent, window_dialog) == FALSE)
+    if (static_apply (child, parent,
+    layer_child, layer_parent, window_dialog) == FALSE)
       {
       start = gamgi_engine_slist_add_start (start);
       start->data = dlist->data;
       }
     }
+
+  /********************************************************
+   * raise to top window and layer where parent object is *
+   ********************************************************/
+
+  window_parent = GAMGI_CAST_WINDOW layer_parent->object.object;
+  gamgi_gtk_object_raise (layer_parent, window_parent);
   } 
 
 if (cache.above == FALSE)
   {
   /******************************************
-   * link each atom of the list to a child  *
+   * link each listed atom to a child       *
    * object copied from the selected object *
    ******************************************/
 
@@ -600,22 +588,14 @@ if (cache.above == FALSE)
     {
     parent = GAMGI_CAST_OBJECT dlist->data;
     layer_parent = gamgi_engine_find_layer (parent);
-    window_parent =  GAMGI_CAST_WINDOW layer_parent->object.object;
 
-    child_new = gamgi_engine_copy_object (child);
-    gamgi_engine_link_object_layer (child_new, layer_parent);
-
-    if (static_apply (child_new, parent, layer_parent, layer_parent,
-    window_parent, window_parent, window_dialog) == FALSE)
+    if (static_apply (child, parent,
+    layer_parent, layer_parent, window_dialog) == FALSE)
       {
       start = gamgi_engine_slist_add_start (start);
       start->data = dlist->data;
-
-      gamgi_engine_unlink_object (child_new);
-      gamgi_engine_remove_object (child_new);
       }
     }
-
   }
 
 gamgi_io_error_list (start, window_dialog);
@@ -636,13 +616,12 @@ gamgi_layer *layer_child, *layer_parent;
 gamgi_atom *atom;
 gamgi_object *child, *parent;
 GtkWidget *dialog = window_dialog->dialog0;
-GdkWindow *drawable;
 
 cache.local = TRUE;
 
-/********************************
- * pick object, get dialog data *
- ********************************/
+/******************************
+ * pick atom, get dialog data *
+ ******************************/
 
 atom = GAMGI_CAST_ATOM gamgi_gtk_object_name_number (dialog,
 "entry_atom", GAMGI_ENGINE_ATOM, window_dialog);
@@ -674,20 +653,13 @@ if (child == window_child->focus)
   gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT
   window_child->layer, window_child);
 
-static_apply (child, parent, layer_child, layer_parent,
-window_child, window_parent, window_dialog);
+static_apply (child, parent, layer_child, layer_parent, window_dialog);
 
 /********************************************************
  * raise to top window and layer where parent object is *
  ********************************************************/
 
-drawable = gtk_widget_get_window (window_parent->window);
-gdk_window_raise (drawable);
-if (layer_parent != window_parent->layer)
-  {
-  gamgi_gtk_object_layer_local (layer_parent, window_parent);
-  gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT layer_parent, window_parent);
-  }
+gamgi_gtk_object_raise (layer_parent, window_parent);
 
 /***************************************************
  * redraw drawing area for parent and child window *
