@@ -222,7 +222,7 @@ gamgi_dlist *dlist, *atoms;
 
 if (gamgi->atoms == NULL)
   { gamgi_gtk_dialog_message_create ("Error",
-  "Empty list of atoms objects", window); return; }
+  "Empty list of atom objects", window); return; }
 
 /************************************************
  * for all windows: save layers as undo layers, *
