@@ -28,6 +28,7 @@
 #include "gamgi_math_vector.h"
 #include "gamgi_chem_bond.h"
 #include "gamgi_io_token.h"
+#include "gamgi_io_error.h"
 #include "gamgi_global_selection.h"
 
 enum { STATIC_LAYER, STATIC_LOCAL };
@@ -190,9 +191,10 @@ else
 static gamgi_bool static_grab (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
+GtkWidget *combo;
 GtkWidget *entry;
-GtkWidget *button;
 const char *name;
+int row;
 
 /********
  * name *
@@ -228,8 +230,9 @@ if (gamgi_io_token_int_scan (name, &cache.number, 1, INT_MAX) == FALSE)
  *********/
 
 cache.layer = NULL;
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_layer");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_location");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == STATIC_LAYER)
   {
   cache.layer = GAMGI_CAST_LAYER gamgi_gtk_object_name_number (dialog,
   "entry_layer", GAMGI_ENGINE_LAYER, NULL);
@@ -338,6 +341,7 @@ gamgi_window *window_mouse;
 gamgi_layer *layer;
 gamgi_object *object;
 gamgi_dlist *dlist;
+gamgi_slist *start;
 
 cache.local = FALSE;
 
@@ -381,8 +385,14 @@ else
  * copy clusters according to dialog data *
  ******************************************/
 
+start = NULL;
 for (dlist = gamgi->clusters; dlist != NULL; dlist = dlist->next)
-  static_apply (GAMGI_CAST_CLUSTER dlist->data, window_dialog);
+  if (static_apply (GAMGI_CAST_CLUSTER dlist->data, window_dialog) == FALSE)
+    {
+    start = gamgi_engine_slist_add_start (start);
+    start->data = dlist->data;
+    }
+gamgi_io_error_list (start, window_dialog);
 
 if (layer == NULL)
   {
@@ -538,9 +548,11 @@ void gamgi_gtk_cluster_copy_press (gamgi_window *window_mouse,
 GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 GtkWidget *dialog = window_dialog->dialog0;
+GtkWidget *combo;
 GtkWidget *button;
 GtkWidget *entry;
 const char *name;
+int row;
 
 /***********************************************
  * local location is active only in List mode, *
@@ -550,8 +562,9 @@ const char *name;
  * the location, the object to copy is local   *
  ***********************************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_local");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE) return;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_location");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == STATIC_LOCAL) return;
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_cluster");
