@@ -154,7 +154,7 @@ else
 
 }
 
-static void static_start_line (gamgi_window *window)
+static void static_start_scope (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *button_cell;
@@ -272,24 +272,24 @@ static void static_cell (GtkWidget *widget, void *data)
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 gamgi_cell *cell;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *vbox_line, *vbox_projection;
+GtkWidget *vbox_scope, *vbox_projection;
 
-vbox_line = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_line");
+vbox_scope = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_scope");
 vbox_projection = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_projection");
 
 cell = GAMGI_CAST_CELL gamgi_gtk_object_name_number (dialog,
 "entry_cell", GAMGI_ENGINE_CELL, window);
 if (cell != NULL && cell->type == GAMGI_PHYS_PROJECTION)
   {
-  gtk_widget_hide (vbox_line);
+  gtk_widget_hide (vbox_scope);
   gtk_widget_show (vbox_projection);
   static_start_projection (window);
   }
 else
   {
   gtk_widget_hide (vbox_projection);
-  gtk_widget_show (vbox_line);
-  static_start_line (window);
+  gtk_widget_show (vbox_scope);
+  static_start_scope (window);
 
   static_nodes (cell, window);
   }
@@ -555,14 +555,13 @@ if (gamgi_phys_direction_line (*atom1, *atom2) == FALSE)
 return TRUE;
 }
 
-static gamgi_bool static_ok_line (gamgi_direction *direction, 
+static gamgi_bool static_ok_scope (gamgi_direction *direction, 
 gamgi_cell *cell, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
 GtkWidget *combo;
 const char *name;
-int row;
 
 /*********************************
  * get type of direction link:   *
@@ -570,11 +569,7 @@ int row;
  *********************************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
-if (row == GAMGI_GTK_ALL - 1) direction->autonomy = GAMGI_GTK_ALL;
-if (row == GAMGI_GTK_PARTIAL - 1) direction->autonomy = GAMGI_GTK_PARTIAL;
-if (row == GAMGI_GTK_NONE - 1) direction->autonomy = GAMGI_GTK_NONE;
+direction->autonomy = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 /**************************
  * get scanning thickness *
@@ -816,7 +811,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
     }
   else
     {
-    valid = static_ok_line (direction, cell, window);
+    valid = static_ok_scope (direction, cell, window);
     if (valid == FALSE) return;
     }
 
@@ -830,7 +825,7 @@ else
   valid = static_ok_atoms (direction, &atom1, &atom2, window);
   if (valid == FALSE) return;
 
-  valid = static_ok_line (direction, NULL, window);
+  valid = static_ok_scope (direction, NULL, window);
   if (valid == FALSE) return;
   }
 
@@ -1050,11 +1045,11 @@ if (state == TRUE)
   gtk_widget_set_sensitive (label_o3, TRUE);
   gtk_widget_set_sensitive (label_o4, TRUE);
 
-  sprintf (token, "%d", GAMGI_PHYS_DIRECTION_NODE_O1);
+  sprintf (token, "%d", GAMGI_PHYS_NODE_O1);
   gtk_entry_set_text (GTK_ENTRY (entry_o1), token);
-  sprintf (token, "%d", GAMGI_PHYS_DIRECTION_NODE_O2);
+  sprintf (token, "%d", GAMGI_PHYS_NODE_O2);
   gtk_entry_set_text (GTK_ENTRY (entry_o2), token);
-  sprintf (token, "%d", GAMGI_PHYS_DIRECTION_NODE_O3);
+  sprintf (token, "%d", GAMGI_PHYS_NODE_O3);
   gtk_entry_set_text (GTK_ENTRY (entry_o3), token);
   }
 else
@@ -1433,15 +1428,15 @@ gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_object_set_data (G_OBJECT (dialog), "button_trace", button);
 gtk_widget_show (button);
 
-/*************
- * Line page *
- *************/
+/**************
+ * Scope page *
+ **************/
 
 vbox_page = gtk_vbox_new (FALSE, 5);
-label = gtk_label_new (" Line ");
+label = gtk_label_new (" Scope ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
 gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
-g_object_set_data (G_OBJECT (dialog), "vbox_line", vbox_page);
+g_object_set_data (G_OBJECT (dialog), "vbox_scope", vbox_page);
 gtk_widget_show (vbox_page);
 
 vbox_center = gtk_vbox_new (TRUE, 0);
