@@ -19,7 +19,7 @@ static void static_nodes (gamgi_cell *cell, gamgi_window *window);
 
 static void static_autonomy (GtkWidget *widget, void *data);
 
-static void static_start_line (gamgi_window *window);
+static void static_start_scope (gamgi_window *window);
 
 static void static_start_projection (gamgi_window *window);
 
@@ -43,7 +43,7 @@ gamgi_cell **cell, gamgi_window *window);
 static gamgi_bool static_ok_atoms (gamgi_direction *direction,
 gamgi_atom **atom1, gamgi_atom **atom2, gamgi_window *window);
 
-static gamgi_bool static_ok_line (gamgi_direction *direction,
+static gamgi_bool static_ok_scope (gamgi_direction *direction,
 gamgi_cell *cell, double *thickness, gamgi_window *window);
 
 static gamgi_bool static_ok_projection (gamgi_direction *direction,
