@@ -22,7 +22,7 @@
 #include "gamgi_math_measure.h"
 #include "gamgi_io_token.h"
 
-static GtkWidget *static_status (gamgi_window *window, int *page, int *property)
+static GtkWidget *static_status (gamgi_window *window, int *page, int *quantity)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *notebook;
@@ -38,11 +38,11 @@ notebook = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "notebook");
 vbox = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), *page);
 
 /****************
- * get property *
+ * get quantity *
  ****************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (vbox), "combo_property");
-*property = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (vbox), "combo_quantity");
+*quantity = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 return vbox;
 }
@@ -51,14 +51,14 @@ static gamgi_enum static_class (gamgi_window *window)
 {
 GtkWidget* vbox;
 GtkWidget *entry;
-int page, property;
+int page, quantity;
 const char *name;
 
 /********************************************
  * select object class from notebook status *
  ********************************************/
 
-vbox = static_status (window, &page, &property);
+vbox = static_status (window, &page, &quantity);
 
 /***********
  * level 0 *
@@ -83,14 +83,14 @@ switch (page)
 switch (page)
   {
   case 0:
-  if (property == 2 && gamgi_io_token_check (name) == FALSE)
+  if (quantity == 2 && gamgi_io_token_check (name) == FALSE)
     return GAMGI_ENGINE_ATOM;
   break;
 
   case 1:
-  if (property == 0 && gamgi_io_token_check (name) == FALSE)
+  if (quantity == 0 && gamgi_io_token_check (name) == FALSE)
     return GAMGI_ENGINE_DIRECTION;
-  if (property == 1 && gamgi_io_token_check (name) == FALSE)
+  if (quantity == 1 && gamgi_io_token_check (name) == FALSE)
     return GAMGI_ENGINE_PLANE;
   break;
   }
@@ -98,7 +98,7 @@ switch (page)
 return GAMGI_ENGINE_DIRECTION;
 }
 
-static GtkWidget *static_entry (GtkWidget *vbox, int page, int property)
+static GtkWidget *static_entry (GtkWidget *vbox, int page, int quantity)
 {
 GtkWidget *entry;
 const char *name;
@@ -125,14 +125,14 @@ switch (page)
 switch (page)
   {
   case 0:
-  if (property == 2 && gamgi_io_token_check (name) == FALSE)
+  if (quantity == 2 && gamgi_io_token_check (name) == FALSE)
     return entry;
   break;
  
   case 1:
-  if (property == 0 && gamgi_io_token_check (name) == FALSE)
+  if (quantity == 0 && gamgi_io_token_check (name) == FALSE)
     return entry;
-  if (property == 1 && gamgi_io_token_check (name) == FALSE)
+  if (quantity == 1 && gamgi_io_token_check (name) == FALSE)
     return entry;
   break;
   }
@@ -227,8 +227,8 @@ entry = g_object_get_data (G_OBJECT (vbox), "entry_value");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
 }
 
-static void static_property (GtkWidget *vbox,
-int page, int property, gamgi_window *window)
+static void static_quantity (GtkWidget *vbox,
+int page, int quantity, gamgi_window *window)
 {
 GtkWidget *label1;
 GtkWidget *entry1;
@@ -265,7 +265,7 @@ switch (page)
 switch (page)
   {
   case 0:
-  switch (property)
+  switch (quantity)
     {
     case 0: case 1:
     gtk_entry_set_text (GTK_ENTRY (entry1), "");
@@ -279,7 +279,7 @@ switch (page)
   break;
 
   case 1:
-  switch (property)
+  switch (quantity)
     {
     case 0:
     gtk_label_set_text (GTK_LABEL (label1), "Direction");
@@ -299,7 +299,7 @@ switch (page)
 switch (page)
   {
   case 0:
-  switch (property)
+  switch (quantity)
     {
     case 0: case 1:
     gtk_widget_set_sensitive (entry1, FALSE);
@@ -314,7 +314,7 @@ switch (page)
   break;
 
   case 1:
-  switch (property)
+  switch (quantity)
     {
     case 0: case 1:
     gtk_widget_set_sensitive (entry1, TRUE);
@@ -330,19 +330,19 @@ static void static_activate (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *vbox;
-int page, property;
+int page, quantity;
 
 /***********************
  * get notebook status *
  ***********************/
 
-vbox = static_status (window, &page, &property);
+vbox = static_status (window, &page, &quantity);
 
 /*******************
- * update property *
+ * update quantity *
  *******************/
 
-static_property (vbox, page, property, window);
+static_quantity (vbox, page, quantity, window);
 }
 
 /******************** internal function ****************
@@ -364,9 +364,9 @@ GtkWidget *vbox;
  ***********************************************/
 
 vbox = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), page);
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (vbox), "combo_property");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (vbox), "combo_quantity");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
-static_property (vbox, page, 0, window);
+static_quantity (vbox, page, 0, window);
 }
 
 /******************** internal function ****************
@@ -387,13 +387,13 @@ GtkWidget* vbox;
 GtkWidget *entry;
 char token[GAMGI_ENGINE_TOKEN];
 double length, angle;
-int page, property;
+int page, quantity;
 
 /**************
  * get status *
  **************/
 
-vbox = static_status (window, &page, &property);
+vbox = static_status (window, &page, &quantity);
 
 /***************
  * get objects *
@@ -407,7 +407,7 @@ if (direction0 == NULL) return;
 switch (page)
   {
   case 0:
-  switch (property)
+  switch (quantity)
     {
     case 2:
     atom1 = static_atom (vbox, "entry_object1", window);
@@ -416,7 +416,7 @@ switch (page)
   break;
 
   case 1:
-  switch (property)
+  switch (quantity)
     {
     case 0:
     direction1 = static_direction (vbox, "entry_object1", window);
@@ -448,7 +448,7 @@ if (direction1 == direction0)
 switch (page)
   {
   case 0:
-  switch (property)
+  switch (quantity)
     {
     case 0:
     if (gamgi_math_measure_length_direction (direction0, &length) == FALSE)
@@ -481,7 +481,7 @@ switch (page)
   break;
 
   case 1:
-  switch (property)
+  switch (quantity)
     {
     case 0:
     if (gamgi_math_measure_angle_2direction (direction0, direction1, &angle) == FALSE)
@@ -522,13 +522,13 @@ GtkWidget *notebook;
  ****************/
 
 notebook = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "notebook");
-gtk_notebook_set_page (GTK_NOTEBOOK (notebook), 0);
+gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 0);
 
-g_signal_connect (GTK_OBJECT (notebook), "switch_page",
+g_signal_connect (notebook, "switch_page",
 G_CALLBACK (static_switch), window);
 
 /****************
- * set property *
+ * set quantity *
  ****************/
 
 static_switch (GTK_NOTEBOOK (notebook), NULL, 0, window);
@@ -540,9 +540,9 @@ gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget* vbox;
 GtkWidget *entry;
 char string[2 * GAMGI_ENGINE_TOKEN];
-int page, property;
+int page, quantity;
 
-vbox = static_status (window, &page, &property);
+vbox = static_status (window, &page, &quantity);
 
 /****************
  * clean output *
@@ -555,21 +555,21 @@ gtk_entry_set_text (GTK_ENTRY (entry), "");
  * enter object *
  ****************/
 
-entry = static_entry (vbox, page, property);
+entry = static_entry (vbox, page, quantity);
 if (entry == NULL)
   {
   static_reset (vbox, page);
-  entry = static_entry (vbox, page, property);
+  entry = static_entry (vbox, page, quantity);
   }
 
 sprintf (string, "%s %d", object->name, object->number);
 gtk_entry_set_text (GTK_ENTRY (entry), string);
 
 /********************
- * measure property *
+ * measure quantity *
  ********************/
 
-entry = static_entry (vbox, page, property);
+entry = static_entry (vbox, page, quantity);
 if (entry == NULL) static_ok (NULL, window);
 }
 
@@ -580,7 +580,7 @@ if (entry == NULL) static_ok (NULL, window);
  *******************************************************/
 
 void gamgi_gtk_direction_measure_press (gamgi_window *window_mouse,
-int x, int y, gamgi_window *window_dialog)
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 /******************************
  * local mouse selection only *
@@ -603,9 +603,8 @@ void gamgi_gtk_direction_measure (GtkWidget *widget, void *data)
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog;
 GtkWidget *notebook;
-GtkWidget *vbox_dialog, *vbox_page, *vbox_frame;
+GtkWidget *vbox_dialog, *vbox_page, *vbox_top;
 GtkWidget *hbox_center, *hbox_left;
-GtkWidget *frame;
 GtkWidget *entry;
 GtkWidget *button;
 GtkWidget *label;
@@ -637,7 +636,6 @@ gtk_widget_show (vbox_dialog);
 notebook = gtk_notebook_new ();
 gtk_box_pack_start (GTK_BOX (vbox_dialog), notebook, FALSE, FALSE, 0);
 gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
-gtk_notebook_set_homogeneous_tabs (GTK_NOTEBOOK (notebook), TRUE);
 g_object_set_data (G_OBJECT (dialog), "notebook", notebook);
 gtk_widget_show (notebook);
 
@@ -648,40 +646,34 @@ gtk_widget_show (notebook);
 label = gtk_label_new ("Length");
 vbox_page = gtk_vbox_new (FALSE, 0);
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (FALSE, 5);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_top = gtk_vbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top);
 
 /*****************
- * Property menu *
+ * Quantity menu *
  *****************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 15);
 gtk_widget_show (hbox_left);
 
-label = gtk_label_new ("Property");
+label = gtk_label_new ("Quantity");
 gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
+g_signal_connect (combo, "changed",
 G_CALLBACK (static_activate), window);
-g_object_set_data (G_OBJECT (vbox_page), "combo_property", combo);
+g_object_set_data (G_OBJECT (vbox_page), "combo_quantity", combo);
 gtk_widget_show (combo);
 
 store = gtk_list_store_new (1, G_TYPE_STRING);
@@ -703,7 +695,7 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
  **********************/
 
 hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 entry = gtk_entry_new ();
@@ -722,7 +714,7 @@ gtk_widget_show (label);
  ************/
 
 hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 entry = gtk_entry_new ();
@@ -742,7 +734,7 @@ gtk_widget_show (label);
  *********/
 
 hbox_left = gtk_hbox_new (FALSE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 entry = gtk_entry_new ();
@@ -763,40 +755,34 @@ gtk_widget_show (label);
 label = gtk_label_new ("Angle");
 vbox_page = gtk_vbox_new (FALSE, 0);
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (FALSE, 5);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_top = gtk_vbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top);
 
 /*****************
- * Property menu *
+ * Quantity menu *
  *****************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 15);
 gtk_widget_show (hbox_left);
 
-label = gtk_label_new ("Property");
+label = gtk_label_new ("Quantity");
 gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
+g_signal_connect (combo, "changed",
 G_CALLBACK (static_activate), window);
-g_object_set_data (G_OBJECT (vbox_page), "combo_property", combo);
+g_object_set_data (G_OBJECT (vbox_page), "combo_quantity", combo);
 gtk_widget_show (combo);
 
 store = gtk_list_store_new (1, G_TYPE_STRING);
@@ -816,7 +802,7 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
  **********************/
 
 hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 entry = gtk_entry_new ();
@@ -835,7 +821,7 @@ gtk_widget_show (label);
  ************/
 
 hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 entry = gtk_entry_new ();
@@ -855,7 +841,7 @@ gtk_widget_show (label);
  *********/
 
 hbox_left = gtk_hbox_new (FALSE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 entry = gtk_entry_new ();
@@ -879,18 +865,16 @@ gtk_widget_show (hbox_center);
 
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_ok), window);
 gtk_widget_show (button);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_task0_remove), window);
 gtk_widget_show (button);
 
