@@ -442,7 +442,7 @@ static_autonomy (NULL, window);
 static_instance (NULL, window);
 }
 
-static void static_start_line (gamgi_window *window)
+static void static_start_scope (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *entry_o1, *entry_o2, *entry_o3;
@@ -463,11 +463,11 @@ static_instance (NULL, window);
 entry_o1 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o1");
 entry_o2 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o2");
 entry_o3 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o3");
-sprintf (token, "%d", GAMGI_PHYS_DIRECTION_NODE_O1);
+sprintf (token, "%d", GAMGI_PHYS_NODE_O1);
 gtk_entry_set_text (GTK_ENTRY (entry_o1), token);
-sprintf (token, "%d", GAMGI_PHYS_DIRECTION_NODE_O2);
+sprintf (token, "%d", GAMGI_PHYS_NODE_O2);
 gtk_entry_set_text (GTK_ENTRY (entry_o2), token);
-sprintf (token, "%d", GAMGI_PHYS_DIRECTION_NODE_O3);
+sprintf (token, "%d", GAMGI_PHYS_NODE_O3);
 gtk_entry_set_text (GTK_ENTRY (entry_o3), token);
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_o4");
@@ -545,9 +545,9 @@ static void static_cell (GtkWidget *widget, void *data)
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 gamgi_cell *cell;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *vbox_line, *vbox_projection;
+GtkWidget *vbox_scope, *vbox_projection;
 
-vbox_line = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_line");
+vbox_scope = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_scope");
 vbox_projection = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_projection");
 
 cell = GAMGI_CAST_CELL gamgi_gtk_object_name_number (dialog,
@@ -556,15 +556,15 @@ if (cell != NULL && cell->type == GAMGI_PHYS_PROJECTION)
   {
   if (gtk_widget_get_visible (vbox_projection) == FALSE)
     static_start_projection (window);
-  gtk_widget_hide (vbox_line);
+  gtk_widget_hide (vbox_scope);
   gtk_widget_show (vbox_projection);
   }
 else
   {
-  if (gtk_widget_get_visible (vbox_line) == FALSE)
-    static_start_line (window);
+  if (gtk_widget_get_visible (vbox_scope) == FALSE)
+    static_start_scope (window);
   gtk_widget_hide (vbox_projection);
-  gtk_widget_show (vbox_line);
+  gtk_widget_show (vbox_scope);
   }
 
 static_nodes (cell, window);
@@ -821,7 +821,7 @@ if (gamgi_phys_direction_line (*atom1, *atom2) == FALSE)
 return TRUE;
 }
 
-static gamgi_bool static_ok_line (gamgi_cell *cell, int *uvw, 
+static gamgi_bool static_ok_scope (gamgi_cell *cell, int *uvw, 
 gamgi_enum vectors, gamgi_enum *type, gamgi_projection *projection,
 gamgi_enum *autonomy, double *thickness, int *node, gamgi_window *window)
 {
@@ -1235,7 +1235,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
       }
     else
       {
-      valid = static_ok_line (cell, uvw, vectors,
+      valid = static_ok_scope (cell, uvw, vectors,
       &type, &projection, &autonomy, &thickness, node, window);
       if (valid == FALSE) return;
       }
@@ -1251,7 +1251,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
     valid = static_ok_atoms (direction, &atom1, &atom2, &inside, window);
     if (valid == FALSE) return;
 
-    valid = static_ok_line (NULL, NULL, 0,
+    valid = static_ok_scope (NULL, NULL, 0,
     &type, &projection, &autonomy, &thickness, NULL, window);
     if (valid == FALSE) return;
     }
@@ -2117,15 +2117,15 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
-/*************
- * Line page *
- *************/
+/**************
+ * Scope page *
+ **************/
 
 vbox_page = gtk_vbox_new (FALSE, 5);
-label = gtk_label_new (" Line ");
+label = gtk_label_new (" Scope ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
 gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
-g_object_set_data (G_OBJECT (dialog), "vbox_line", vbox_page);
+g_object_set_data (G_OBJECT (dialog), "vbox_scope", vbox_page);
 gtk_widget_show (vbox_page);
 
 vbox_center = gtk_vbox_new (TRUE, 0);
