@@ -224,13 +224,13 @@ switch (object->class)
   case GAMGI_ENGINE_PLANE:
   plane = GAMGI_CAST_PLANE object;
   if (plane->reference == GAMGI_ENGINE_CELL) return FALSE;
-  plane->autonomy = GAMGI_GTK_ALL;
+  if (plane->autonomy == GAMGI_GTK_NONE) return FALSE;
   break;
 
   case GAMGI_ENGINE_DIRECTION:
   direction = GAMGI_CAST_DIRECTION object;
   if (direction->reference == GAMGI_ENGINE_CELL) return FALSE;
-  direction->autonomy = GAMGI_GTK_ALL;
+  if (direction->autonomy == GAMGI_GTK_NONE) return FALSE;
   break;
 
   default:
@@ -365,10 +365,7 @@ gamgi_mesa_start_layer (layer, gamgi->layer);
  * start undo and save mechanisms *
  **********************************/
 
-layer->undo = gamgi_engine_dlist_add_start (NULL);
-layer->save = gamgi_engine_dlist_add_start (NULL);
-layer->undo->data = layer;
-layer->save->data = layer;
+gamgi_gtk_history_start (layer);
 
 /************************
  * link layer to window *
@@ -417,6 +414,19 @@ gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT layer_new, window);
 return layer_new;
 }
 
+void gamgi_gtk_object_raise (gamgi_layer *layer, gamgi_window *window)
+{
+GdkWindow *drawable;
+
+drawable = gtk_widget_get_window (window->window);
+gdk_window_raise (drawable);
+if (layer != window->layer)
+  {
+  gamgi_gtk_object_layer_local (layer, window);
+  gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT layer, window);
+  }
+}
+
 void gamgi_gtk_object_link (gamgi_object *child, 
 gamgi_object *parent, gamgi_window *window)
 {
