@@ -28,6 +28,7 @@
 #include "gamgi_math_vector.h"
 #include "gamgi_chem_bond.h"
 #include "gamgi_io_token.h"
+#include "gamgi_io_error.h"
 #include "gamgi_global_selection.h"
 
 enum { STATIC_LAYER, STATIC_LOCAL };
@@ -190,9 +191,10 @@ else
 static gamgi_bool static_grab (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
+GtkWidget *combo;
 GtkWidget *entry;
-GtkWidget *button;
 const char *name;
+int row;
 
 /********
  * name *
@@ -228,8 +230,9 @@ if (gamgi_io_token_int_scan (name, &cache.number, 1, INT_MAX) == FALSE)
  *********/
 
 cache.layer = NULL;
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_layer");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_location");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == STATIC_LAYER)
   {
   cache.layer = GAMGI_CAST_LAYER gamgi_gtk_object_name_number (dialog,
   "entry_layer", GAMGI_ENGINE_LAYER, NULL);
@@ -271,20 +274,31 @@ if (gamgi_io_token_double_scan (name, &cache.shift[2], -DBL_MAX, DBL_MAX) == FAL
 return TRUE;
 }
 
-static gamgi_bool static_apply (gamgi_assembly *assembly, gamgi_window *window)
+static gamgi_bool static_apply (gamgi_group *group, gamgi_window *window)
 {
 gamgi_layer *layer;
-gamgi_assembly *assembly_new = NULL;
+gamgi_group *group_new = NULL;
 gamgi_dlist *atom_start;
 double translate[3];
 int i;
 
+/*************************************************
+ * only objects with full autonomy can be copied *
+ *************************************************/
+
+if (group->autonomy != GAMGI_GTK_ALL)
+  {
+  if (cache.local == TRUE) gamgi_gtk_dialog_message_create
+  ("Error", "Invalid object autonomy", window);
+  return FALSE;
+  }
+
 /*******************
  * find host layer *
  *******************/
 
 if (cache.layer == NULL)
-  layer = gamgi_engine_find_layer (GAMGI_CAST_OBJECT assembly);
+  layer = gamgi_engine_find_layer (GAMGI_CAST_OBJECT group);
 else
   layer = cache.layer;
 
@@ -293,13 +307,13 @@ else
  * as only atoms can own bonds, this list gives    *
  * access to all bonds formed by the scope object. *
  *                                                 *
- * copy assemblys and their contents, cleaning the *
+ * copy groups and their contents, cleaning the    *
  * bonds formed with atoms that are not copied     *
  *                                                 *
  *  remove list of atoms used to clean the bonds   *
  ***************************************************/
 
-atom_start = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT assembly, NULL);
+atom_start = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT group, NULL);
 
 if (cache.local == TRUE)
   gamgi_gtk_history_update (layer, layer->undo, GAMGI_ENGINE_UNDO);
@@ -307,11 +321,11 @@ if (cache.local == TRUE)
 gamgi_math_vector_zero (translate);
 for (i = 0; i < cache.number; i++)
   {
-  assembly_new = gamgi_engine_copy_assembly (assembly);
+  group_new = gamgi_engine_copy_group (group);
   if (cache.name[0] != '\0')
-    strcpy (assembly_new->object.name, cache.name);
+    strcpy (group_new->object.name, cache.name);
 
-  gamgi_engine_link_assembly_layer (assembly_new, layer);
+  gamgi_engine_link_group_layer (group_new, layer);
 
   /**************************************
    * clean the bonds before translating *
@@ -320,7 +334,7 @@ for (i = 0; i < cache.number; i++)
   gamgi_chem_bond_half_clean (atom_start);
 
   gamgi_math_vector_add (translate, cache.shift, translate);
-  gamgi_mesa_translate_assembly (assembly_new, translate);
+  gamgi_mesa_translate_group (group_new, translate);
   }
 
 /************************
@@ -338,6 +352,7 @@ gamgi_window *window_mouse;
 gamgi_layer *layer;
 gamgi_object *object;
 gamgi_dlist *dlist;
+gamgi_slist *start;
 
 cache.local = FALSE;
 
@@ -345,9 +360,9 @@ cache.local = FALSE;
  * get object list, dialog data *
  ********************************/
 
-if (gamgi->assemblys == NULL)
+if (gamgi->groups == NULL)
   { gamgi_gtk_dialog_message_create ("Error",
-  "Empty list of assembly objects", window_dialog); return; }
+  "Empty list of group objects", window_dialog); return; }
 
 if (static_grab (window_dialog) == FALSE) return;
 
@@ -377,12 +392,18 @@ else
   gamgi_gtk_history_update (layer, layer->undo, GAMGI_ENGINE_UNDO);
   }
 
-/*******************************************
- * copy assemblys according to dialog data *
- *******************************************/
+/****************************************
+ * copy groups according to dialog data *
+ ****************************************/
 
-for (dlist = gamgi->assemblys; dlist != NULL; dlist = dlist->next)
-  static_apply (GAMGI_CAST_ASSEMBLY dlist->data, window_dialog);
+start = NULL;
+for (dlist = gamgi->groups; dlist != NULL; dlist = dlist->next)
+  if (static_apply (GAMGI_CAST_GROUP dlist->data, window_dialog) == FALSE)
+    {
+    start = gamgi_engine_slist_add_start (start);
+    start->data = dlist->data;
+    }
+gamgi_io_error_list (start, window_dialog);
 
 if (layer == NULL)
   {
@@ -399,10 +420,10 @@ else
    * top and if layer is not on top, set   *
    * layer as the current layer and object *
    *                                       *
-   * any assembly object can be used here  *
+   * any group object can be used here     *
    *****************************************/
 
-  object = GAMGI_CAST_OBJECT gamgi->assemblys->data;
+  object = GAMGI_CAST_OBJECT gamgi->groups->data;
   gamgi_gtk_object_copy (object, GAMGI_CAST_OBJECT layer, window_dialog);
 
   /********************************************
@@ -421,7 +442,7 @@ static void static_ok_local (gamgi_window *window_dialog)
 {
 gamgi_window *window_mouse;
 gamgi_layer *layer;
-gamgi_assembly *assembly;
+gamgi_group *group;
 GtkWidget *dialog = window_dialog->dialog0;
 
 cache.local = TRUE;
@@ -430,22 +451,22 @@ cache.local = TRUE;
  * pick object, get dialog data *
  ********************************/
 
-assembly = GAMGI_CAST_ASSEMBLY gamgi_gtk_object_name_number (dialog,
-"entry_assembly", GAMGI_ENGINE_ASSEMBLY, window_dialog);
-if (assembly == NULL)
+group = GAMGI_CAST_GROUP gamgi_gtk_object_name_number (dialog,
+"entry_group", GAMGI_ENGINE_GROUP, window_dialog);
+if (group == NULL)
   {
   gamgi_gtk_dialog_message_create ("Error",
-  "Invalid assembly object", window_dialog);
+  "Invalid group object", window_dialog);
   return;
   }
 
 if (static_grab (window_dialog) == FALSE) return;
 
-/******************************************
- * copy assembly according to dialog data *
- ******************************************/
+/***************************************
+ * copy group according to dialog data *
+ ***************************************/
 
-static_apply (assembly, window_dialog);
+static_apply (group, window_dialog);
 
 /******************************************
  * get and save host layer as undo buffer *
@@ -453,7 +474,7 @@ static_apply (assembly, window_dialog);
  ******************************************/
 
 if (cache.layer == NULL)
-  layer = gamgi_engine_find_layer (GAMGI_CAST_OBJECT assembly);
+  layer = gamgi_engine_find_layer (GAMGI_CAST_OBJECT group);
 else
   layer = cache.layer;
 
@@ -463,7 +484,7 @@ else
  * layer as the current layer and object *
  *****************************************/
 
-gamgi_gtk_object_copy (GAMGI_CAST_OBJECT assembly,
+gamgi_gtk_object_copy (GAMGI_CAST_OBJECT group,
 GAMGI_CAST_OBJECT layer, window_dialog);
 
 /********************************************
@@ -538,9 +559,11 @@ void gamgi_gtk_group_copy_press (gamgi_window *window_mouse,
 GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 GtkWidget *dialog = window_dialog->dialog0;
+GtkWidget *combo;
 GtkWidget *button;
 GtkWidget *entry;
 const char *name;
+int row;
 
 /***********************************************
  * local location is active only in List mode, *
@@ -550,8 +573,9 @@ const char *name;
  * the location, the object to copy is local   *
  ***********************************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_local");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE) return;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_location");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == STATIC_LOCAL) return;
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_group");
