@@ -28,6 +28,7 @@
 #include "gamgi_engine_list.h"
 #include "gamgi_engine_dlist.h"
 #include "gamgi_engine_find.h"
+#include "gamgi_engine_number.h"
 #include "gamgi_engine_remove.h"
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_gtk_history.h"
@@ -41,16 +42,37 @@
 #include "gamgi_math_euler.h"
 #include "gamgi_math_position.h"
 #include "gamgi_io_token.h"
+#include "gamgi_io_error.h"
+#include "gamgi_global_selection.h"
 
-/*****************************************************
- * GTK combo box enumerations: static, starting at 0 *
- *****************************************************/
+/*******************************************
+ * enumerations: GAMGI property, GTK combo *
+ *******************************************/
 
-enum { STATIC_TYPE_CONTAINER = 0, STATIC_TYPE_POLYTOPE, STATIC_TYPE_LOCAL };
-enum { STATIC_AUTONOMY_ALL = 0, STATIC_AUTONOMY_PARTIAL, 
+enum { STATIC_NAME, STATIC_TYPE, STATIC_ATOM, STATIC_AUTONOMY,
+STATIC_ELEMENT, STATIC_NUMBER, STATIC_VISIBLE, STATIC_COPLANAR,
+STATIC_TRANSLATION_X, STATIC_TRANSLATION_Y, STATIC_TRANSLATION_Z,
+STATIC_ROTATION_E1, STATIC_ROTATION_E2, STATIC_ROTATION_E3,
+STATIC_STYLE, STATIC_RED, STATIC_GREEN, STATIC_BLUE, STATIC_SCALE };
+
+enum { STATIC_TYPE_CONTAINER, STATIC_TYPE_POLYTOPE, STATIC_TYPE_LOCAL };
+enum { STATIC_AUTONOMY_ALL, STATIC_AUTONOMY_PARTIAL,
 STATIC_AUTONOMY_NONE, STATIC_AUTONOMY_LOCAL };
-enum { STATIC_NUMBER_NUMBER = 0, STATIC_NUMBER_RADIUS, STATIC_NUMBER_LOCAL };
-enum { STATIC_STYLE_WIRED = 0, STATIC_STYLE_SOLID, STATIC_STYLE_LOCAL };
+enum { STATIC_NUMBER_NUMBER, STATIC_NUMBER_RADIUS, STATIC_NUMBER_LOCAL };
+enum { STATIC_STYLE_WIRED, STATIC_STYLE_SOLID, STATIC_STYLE_LOCAL };
+
+static struct {
+gamgi_bool local;
+gamgi_bool new[STATIC_SCALE + 1];
+char name[GAMGI_ENGINE_TOKEN];
+gamgi_atom *atom;
+gamgi_enum type, autonomy;
+double radius, visible, coplanar;
+int element, number;
+double translation[3], rotation[3];
+gamgi_enum faces;
+float red, green, blue;
+double scale; } cache;
 
 static gamgi_bool static_scan (gamgi_group *group, gamgi_dlist *start,
 double *position, gamgi_atom **central)
@@ -497,81 +519,395 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
 }
 
-/****************** internal function ***************
- *                                                  *
- *                    STATIC_GLOBAL                 *
- *                                                  *
- * Makes the group entry (but not the table button) *
- * sensitive when the local button is pressed and   *
- * insensitive when the global button is pressed.   *
- *                                                  *
- ****************************************************/
+/******************** internal function *****************
+ *                                                      *
+ *                        STATIC_LIST                   *
+ *                                                      *
+ ********************************************************/
 
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *hbox, *button;
+GtkWidget *label, *button;
 
-hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_group");
-
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_group");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
-  /****************************
-   * Choose the atom directly *
-   ****************************/
+  /**********************************
+   * modify a single group directly *
+   **********************************/
 
-  gtk_widget_set_sensitive (hbox, TRUE);
+  gtk_label_set_text (GTK_LABEL (label), "Group");
   }
 else
   {
-  /****************************************
-   * Choose the atoms previously selected *
-   ****************************************/
+  /**********************************************
+   * modify multiple groups previously selected *
+   **********************************************/
 
-  gtk_widget_set_sensitive (hbox, FALSE);
+  gtk_label_set_text (GTK_LABEL (label), "Name");
   static_reset (window);
   }
 }
 
-static void static_ok_container (gamgi_group *group, char *group_name, gamgi_window *window)
+static gamgi_bool static_grab_polytope (gamgi_window *window)
 {
-/**********************************************
- * Update the group name, which might be new. *
- **********************************************/
-
-strcpy (group->object.name, group_name);
-}
-
-static void static_ok_polytope (gamgi_group *group, char *group_name, gamgi_window *window)
-{
-gamgi_group *group_old;
-gamgi_atom *atom;
-gamgi_object *parent;
-gamgi_dlist *dlist;
 GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
 GtkWidget *button;
 GtkWidget *combo;
-const char *name;
-gamgi_bool autonomy, faces, inside, copy;
 char token[GAMGI_ENGINE_TOKEN];
+const char *name;
+int row;
+
+/********************
+ * get central atom *
+ ********************/
+
+cache.new[STATIC_ATOM] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_atom");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_ATOM] = TRUE;
+  cache.atom = GAMGI_CAST_ATOM gamgi_gtk_object_name_number (dialog,
+  "entry_atom", GAMGI_ENGINE_ATOM, NULL);
+  if (cache.atom == NULL)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid central atom", window);
+    return FALSE;
+    }
+  }
+
+/***********************************************
+ * get Autonomy: the default is GAMGI_GTK_NONE *
+ ***********************************************/
+
+cache.new[STATIC_AUTONOMY] = FALSE;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row != STATIC_AUTONOMY_LOCAL)
+  { cache.new[STATIC_AUTONOMY] = TRUE; cache.autonomy = row + 1; }
+
+/***********************************
+ * get element for neighbour atoms *
+ ***********************************/
+
+cache.new[STATIC_ELEMENT] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_element");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_ELEMENT] = TRUE;
+  if (gamgi_io_token_alpha_scan (name,
+  token, GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE ||
+  gamgi_chem_atom_number (token, &cache.element) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid neighbours element", window);
+    return FALSE;
+    }
+  }
+
+/*********************************************************************
+ * number of neighbours or maximum radius, counting from the nearest *
+ * one, so for example radius = 1.1 means the range [r, 1.1r] where  *
+ * r is the distance from central to the nearest neighbour           *
+ *********************************************************************/
+
+cache.number = 0; cache.radius = 0.0;
+cache.new[STATIC_NUMBER] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_NUMBER] = TRUE;
+  button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_number");
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+    {
+    if (gamgi_io_token_int_scan (name,
+    &cache.number, 2, INT_MAX) == FALSE)
+      {
+      gamgi_gtk_dialog_message_create ("Error",
+      "Invalid neighbours number", window);
+      return FALSE;
+      }
+    }
+  else
+    {
+    if (gamgi_io_token_double_scan (name,
+    &cache.radius, GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
+      {
+      gamgi_gtk_dialog_message_create ("Error",
+      "Invalid neighbours maximum radius", window);
+      return FALSE;
+      }
+    }
+  }
+
+/*************************************
+ * face Tolerance: Visible, Coplanar *
+ *************************************/
+
+cache.new[STATIC_VISIBLE] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_visible");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_VISIBLE] = TRUE;
+  if (gamgi_io_token_double_scan (name, &cache.visible,
+  0.0, GAMGI_CHEM_POLYTOPE_TOLERANCE_VISIBLE_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error",
+    "Invalid visible face tolerance", window);
+    return FALSE;
+    }
+  }
+
+cache.new[STATIC_COPLANAR] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_coplanar");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  if (gamgi_io_token_double_scan (name, &cache.coplanar,
+  0.0, GAMGI_CHEM_POLYTOPE_TOLERANCE_COPLANAR_MAX) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error",
+    "Invalid coplanar face tolerance", window);
+    return FALSE;
+    }
+  }
+
+if (cache.autonomy == GAMGI_GTK_ALL)
+  {
+  /****************************
+   * origin x,y,z coordinates *
+   ****************************/
+
+  cache.new[STATIC_TRANSLATION_X] = FALSE;
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
+  name = gtk_entry_get_text (GTK_ENTRY (entry));
+  if (gamgi_io_token_check (name) == TRUE)
+    {
+    cache.new[STATIC_TRANSLATION_X] = TRUE;
+    if (gamgi_io_token_double_scan (name,
+    &cache.translation[0], -DBL_MAX, DBL_MAX) == FALSE)
+      {
+      gamgi_gtk_dialog_message_create ("Error", "Invalid position", window);
+      return FALSE;
+      }
+    }
+
+  cache.new[STATIC_TRANSLATION_Y] = FALSE;
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
+  name = gtk_entry_get_text (GTK_ENTRY (entry));
+  if (gamgi_io_token_check (name) == TRUE)
+    {
+    cache.new[STATIC_TRANSLATION_Y] = TRUE;
+    if (gamgi_io_token_double_scan (name,
+    &cache.translation[1], -DBL_MAX, DBL_MAX) == FALSE)
+      {
+      gamgi_gtk_dialog_message_create ("Error", "Invalid position", window);
+      return FALSE;
+      }
+    }
+
+  cache.new[STATIC_TRANSLATION_Z] = FALSE;
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
+  name = gtk_entry_get_text (GTK_ENTRY (entry));
+  if (gamgi_io_token_check (name) == TRUE)
+    {
+    cache.new[STATIC_TRANSLATION_Z] = TRUE;
+    if (gamgi_io_token_double_scan (name,
+    &cache.translation[2], -DBL_MAX, DBL_MAX) == FALSE)
+      {
+      gamgi_gtk_dialog_message_create ("Error", "Invalid position", window);
+      return FALSE;
+      }
+    }
+
+  /*************************
+   * e1,e2,e3 euler angles *
+   *************************/
+
+  cache.new[STATIC_ROTATION_E1] = FALSE;
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e1");
+  name = gtk_entry_get_text (GTK_ENTRY (entry));
+  if (gamgi_io_token_check (name) == TRUE)
+    {
+    cache.new[STATIC_ROTATION_E1] = TRUE;
+    if (gamgi_io_token_double_scan (name,
+    &cache.rotation[0], 0.0, 180.0) == FALSE)
+      {
+      gamgi_gtk_dialog_message_create ("Error", "Invalid angle data", window);
+      return FALSE;
+      }
+    }
+
+  cache.new[STATIC_ROTATION_E2] = FALSE;
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e2");
+  name = gtk_entry_get_text (GTK_ENTRY (entry));
+  if (gamgi_io_token_check (name) == TRUE)
+    {
+    cache.new[STATIC_ROTATION_E2] = TRUE;
+    if (gamgi_io_token_double_scan (name,
+    &cache.rotation[1], 0.0, 360.0) == FALSE)
+      {
+      gamgi_gtk_dialog_message_create ("Error", "Invalid angle data", window);
+      return FALSE;
+      }
+    }
+
+  cache.new[STATIC_ROTATION_E3] = FALSE;
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e3");
+  name = gtk_entry_get_text (GTK_ENTRY (entry));
+  if (gamgi_io_token_check (name) == TRUE)
+    {
+    cache.new[STATIC_ROTATION_E3] = TRUE;
+    if (gamgi_io_token_double_scan (name,
+    &cache.rotation[2], 0.0, 360.0) == FALSE)
+      {
+      gamgi_gtk_dialog_message_create ("Error", "Invalid angle data", window);
+      return FALSE;
+      }
+    }
+  }
+
+/**********************************
+ * style, red, green, blue, scale *
+ **********************************/
+
+cache.new[STATIC_STYLE] = FALSE;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row != STATIC_STYLE_LOCAL)
+  {
+  cache.new[STATIC_STYLE] = TRUE;
+  if (row == STATIC_STYLE_WIRED) cache.faces = FALSE;
+  if (row == STATIC_STYLE_SOLID) cache.faces = TRUE;
+  }
+
+cache.new[STATIC_RED] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_red");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_RED] = TRUE;
+  if (gamgi_io_token_float_scan (name,
+  &cache.red, 0.0, 1.0) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid color", window);
+    return FALSE;
+    }
+  }
+
+cache.new[STATIC_GREEN] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_green");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_GREEN] = TRUE;
+  if (gamgi_io_token_float_scan (name,
+  &cache.green, 0.0, 1.0) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid color", window);
+    return FALSE;
+    }
+  }
+
+cache.new[STATIC_BLUE] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_blue");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_BLUE] = TRUE;
+  if (gamgi_io_token_float_scan (name,
+  &cache.blue, 0.0, 1.0) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid color", window);
+    return FALSE;
+    }
+  }
+
+cache.new[STATIC_SCALE] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_SCALE] = TRUE;
+  if (gamgi_io_token_double_scan (name,
+  &cache.scale, GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid scale", window);
+    return FALSE;
+    }
+  }
+
+return TRUE;
+}
+
+static gamgi_bool static_grab (gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *combo;
+
+/******************
+ * get group type *
+ ******************/
+
+cache.new[STATIC_TYPE] = FALSE;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_type");
+cache.type = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (cache.type != STATIC_TYPE_LOCAL) cache.new[STATIC_TYPE] = TRUE;
+
+if (cache.type == STATIC_TYPE_POLYTOPE) return static_grab_polytope (window);
+
+return TRUE;
+}
+
+static gamgi_bool static_apply (gamgi_group *group, gamgi_window *window)
+{
+gamgi_group *group_old;
+gamgi_layer *layer;
+gamgi_atom *atom;
+gamgi_object *parent;
+gamgi_dlist *dlist;
+char name[GAMGI_ENGINE_TOKEN];
+gamgi_bool autonomy, faces, inside, copy;
 double euler[3], origin[3];
-double radius, visible, coplanar, scale;
+double visible, coplanar, scale;
 float red, green, blue;
 int element, number;
-int independent, row;
+int independent;
 
-/**************************
- * get initial parameters *
- **************************/
+if ((cache.type == STATIC_TYPE_CONTAINER && group->type == GAMGI_CHEM_POLYTOPE)
+|| (cache.type == STATIC_TYPE_POLYTOPE && group->type == GAMGI_CHEM_CONTAINER))
+  {
+  if (cache.local == TRUE)
+    gamgi_gtk_dialog_message_create ("Error", "Invalid group change", window);
+  return FALSE;
+  }
+
+if (cache.type != STATIC_TYPE_POLYTOPE)
+  {
+  if (cache.new[STATIC_NAME] == TRUE)
+    { strcpy (group->object.name, cache.name); return TRUE; }
+  }
+
+/*************************
+ * import data from group *
+ *************************/
+
+strcpy (name, group->object.name);
 
 autonomy = group->autonomy;
 element = group->element;
 number = group->number;
+
 visible = group->visible;
 coplanar = group->coplanar;
+
 faces = group->faces;
 red = group->red;
 green = group->green;
@@ -581,22 +917,47 @@ scale = group->object.scale;
 gamgi_math_position_group_rotation_get (group, euler);
 gamgi_math_position_group_translation_get (group, origin);
 
-/***************************
- * 1) Get old central atom *
- * 2) Get new central atom *
- ***************************/
+atom = NULL;
+layer = gamgi_engine_find_layer (GAMGI_CAST_OBJECT group);
+atom = gamgi_engine_find_atom_layer (group->atom, layer);
 
-atom = gamgi_engine_find_atom_layer (group->atom, window->layer);
+/******************
+ * apply new data *
+ ******************/
+
+if (cache.new[STATIC_NAME] == TRUE) strcpy (name, cache.name);
+
+if (cache.new[STATIC_ATOM] == TRUE) atom = cache.atom;
+if (cache.new[STATIC_AUTONOMY] == TRUE) autonomy = cache.autonomy;
+if (cache.new[STATIC_ELEMENT] == TRUE) element = cache.element;
+if (cache.new[STATIC_NUMBER] == TRUE) number = cache.number;
+
+if (cache.new[STATIC_VISIBLE] == TRUE) visible = cache.visible;
+if (cache.new[STATIC_COPLANAR] == TRUE) coplanar = cache.coplanar;
+
+if (cache.new[STATIC_TRANSLATION_X] == TRUE) origin[0] = cache.translation[0];
+if (cache.new[STATIC_TRANSLATION_Y] == TRUE) origin[1] = cache.translation[1];
+if (cache.new[STATIC_TRANSLATION_Z] == TRUE) origin[2] = cache.translation[2];
+
+if (cache.new[STATIC_ROTATION_E1] == TRUE) euler[0] = cache.rotation[0];
+if (cache.new[STATIC_ROTATION_E2] == TRUE) euler[1] = cache.rotation[1];
+if (cache.new[STATIC_ROTATION_E3] == TRUE) euler[2] = cache.rotation[2];
+
+if (cache.new[STATIC_STYLE] == TRUE) faces = cache.faces;
+if (cache.new[STATIC_RED] == TRUE) red = cache.red;
+if (cache.new[STATIC_GREEN] == TRUE) green = cache.green;
+if (cache.new[STATIC_BLUE] == TRUE) blue = cache.blue;
+if (cache.new[STATIC_SCALE] == TRUE) scale = cache.scale;
+
+/****************************
+ * check data compatibility *
+ ****************************/
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_atom");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_check (name) == TRUE)
-  atom = GAMGI_CAST_ATOM gamgi_gtk_object_name_number (dialog,
-  "entry_atom", GAMGI_ENGINE_ATOM, window);
 if (atom == NULL)
   {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid central atom", window);
-  return;
+  if (cache.local == TRUE)
+    gamgi_gtk_dialog_message_create ("Error", "Invalid central atom", window);
+  return FALSE;
   }
 
 inside = FALSE;
@@ -607,222 +968,44 @@ else
   if (parent->class == GAMGI_ENGINE_GROUP || parent->class == GAMGI_ENGINE_PLANE ||
   parent->class == GAMGI_ENGINE_DIRECTION)
     {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid central atom", window);
-    return;
+    if (cache.local == TRUE)
+      gamgi_gtk_dialog_message_create ("Error", "Invalid central atom", window);
+    return FALSE;
     }
   }
 
-/***********************************************
- * get Autonomy: the default is GAMGI_GTK_NONE *
- ***********************************************/
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-if (row < STATIC_AUTONOMY_LOCAL) autonomy = row + 1;
-
-/*********************************************************************
- * number of neighbours or maximum radius, counting from the nearest *
- * one, so for example radius = 1.1 means the range [r, 1.1r] where  *
- * r is the distance from central to the nearest neighbour           *
- *********************************************************************/
-
-radius = 0.0;
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_check (name) == TRUE)
-  {
-  button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_number");
-  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
-    {
-    if (gamgi_io_token_int_scan (name, &number, 2, INT_MAX) == FALSE)
-      {
-      gamgi_gtk_dialog_message_create ("Error", 
-      "Invalid neighbours number", window);
-      return;
-      }
-    }
-  else
-    {
-    if (gamgi_io_token_double_scan (name, &radius,
-    GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
-      {
-      gamgi_gtk_dialog_message_create ("Error",
-      "Invalid neighbours maximum radius", window);
-      return;
-      }
-    number = 0;
-    }
-  }
-
-/***********************************
- * get element for neighbour atoms *
- ***********************************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_element");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_check (name) == TRUE && (gamgi_io_token_alpha_scan (name, 
-token, GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE || 
-gamgi_chem_atom_number (token, &element) == FALSE))
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid neighbours element", window);
-  return;
-  }
-
-if (autonomy == GAMGI_GTK_ALL)
-  {
-  /****************************
-   * origin x,y,z coordinates *
-   ****************************/
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &origin[0], -DBL_MAX, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid position data", window);
-    return;
-    }
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &origin[1], -DBL_MAX, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid position data", window);
-    return;
-    }
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &origin[2], -DBL_MAX, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid position data", window);
-    return;
-    }
-
-  /*************************
-   * e1,e2,e3 euler angles *
-   *************************/
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e1");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &euler[0], 0.0, 180.0) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid angle data", window);
-    return;
-    }
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e2");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &euler[1], 0.0, 360.0) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid angle data", window);
-    return;
-    }
-
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e3");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &euler[2], 0.0, 360.0) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid angle data", window);
-    return;
-    }
-  }
-
-/*************
- * get Style *
- *************/
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-if (row < STATIC_STYLE_LOCAL) faces = row;
-
-/*************
- * get Color *
- *************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_red");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_check (name) == TRUE &&
-gamgi_io_token_float_scan (name, &red, 0.0, 1.0) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid color", window);
-  return;
-  }
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_green");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_check (name) == TRUE &&
-gamgi_io_token_float_scan (name, &green, 0.0, 1.0) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid color", window);
-  return;
-  }
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_blue");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_check (name) == TRUE &&
-gamgi_io_token_float_scan (name, &blue, 0.0, 1.0) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid color", window);
-  return;
-  }
-
-/*************
- * get Scale *
- *************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name,
-&scale, GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid plane scale", window);
-  return;
-  }
-
-/****************
- * global tests *
- ****************/
-
-if (gamgi_engine_find_object (GAMGI_CAST_OBJECT atom, window->focus) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid searching scope for central atom", window);
-  return;
-  }
-
 /*************************************************************************
  * polytope groups with autonomy all can be modified to autonomy partial *
  * or none, as long as the central atom in the original position can     *
  * replace that entered by the user, later removed with the group        *
  *************************************************************************/
 
-if (group->autonomy == GAMGI_GTK_ALL && autonomy != GAMGI_GTK_ALL && 
+if (group->autonomy == GAMGI_GTK_ALL && autonomy != GAMGI_GTK_ALL &&
 inside == TRUE && static_find (group, &atom) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid central atom", window);
-  return;
+  return FALSE;
   }
 
-/**********************************
- * input data is ok: save History *
- **********************************/
+/***************************************
+ * Save current layer as undo buffer   *
+ * layer so it can be recovered later. *
+ ***************************************/
 
-gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
+if (cache.local == TRUE)
+  gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
+
+/*****************************************
+ * export data to group: reset position; *
+ * reset arrays, prepare building arrays *
+ *****************************************/
 
 group_old = gamgi_engine_create_group ();
 gamgi_engine_copy_out_group (group, group_old);
+group_old->object.number = gamgi_engine_number_group_get ();
 group_old->object.selection = NULL;
 parent = group->object.object;
 
-/**************
- * reset data *
- **************/
-
 free (group->points);
 free (group->loops);
 group->points = NULL;
@@ -846,7 +1029,7 @@ copy = (group->autonomy != GAMGI_GTK_ALL || autonomy != GAMGI_GTK_ALL || inside
 if (group->autonomy == GAMGI_GTK_ALL && copy == TRUE)
   {
   /*************************************************
-   * Before removing the plane, check if the       *
+   * Before removing the group, check if the       *
    * current object is affected. In this case, the *
    * current layer becomes the new current object. *
    *************************************************/
@@ -881,11 +1064,11 @@ else
   dlist = gamgi_engine_dlist_atom_group (group, NULL);
   }
 
-/************************************************************
- * save new data: update the group name, which might be new *
- ************************************************************/
+/*****************
+ * save new data *
+ *****************/
 
-strcpy (group->object.name, group_name);
+strcpy (group->object.name, name);
 group->autonomy = autonomy;
 group->element = element;
 group->number = number;
@@ -902,7 +1085,7 @@ group->object.scale = scale;
  * number of independent atom positions that were found *
  ********************************************************/
 
-independent = gamgi_chem_polytope (dlist, group, atom, FALSE, radius, copy, NULL);
+independent = gamgi_chem_polytope (dlist, group, atom, FALSE, cache.radius, copy, NULL);
 if (independent < 2)
   {
   if (group->object.object == NULL)
@@ -910,9 +1093,9 @@ if (independent < 2)
   gamgi_engine_copy_out_group (group_old, group);
   gamgi_engine_remove_group (group_old);
 
-  gamgi_gtk_dialog_message_create ("Error", 
+  gamgi_gtk_dialog_message_create ("Error",
   "Insufficient number of valid neighbours", window);
-  return;
+  return FALSE;
   }
 else if (independent < 4 && copy == TRUE)
   {
@@ -921,64 +1104,151 @@ else if (independent < 4 && copy == TRUE)
   }
 else
   {
-  gamgi_engine_remove_group (group_old);
   gamgi_math_position_group_rotation_set (group, euler);
   gamgi_math_position_group_translation_set (group, origin);
+  gamgi_engine_remove_group (group_old);
   }
+
+return TRUE;
+}
+ 
+static void static_ok_global (gamgi_window *window)
+{
+gamgi_dlist *dlist;
+gamgi_slist *start;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+const char *name;
+
+cache.local = FALSE;
+
+if (gamgi->groups == NULL)
+  { gamgi_gtk_dialog_message_create ("Error",
+  "Empty list of group objects", window); return; }
+
+/****************************
+ * Pick name (possibly new) *
+ ****************************/
+
+cache.new[STATIC_NAME] = FALSE;
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_group");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_check (name) == TRUE)
+  {
+  cache.new[STATIC_NAME] = TRUE;
+  if (gamgi_io_token_alpha_scan (name,
+  cache.name, GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid group identity", window);
+    return;
+    }
+  }
+
+if (static_grab (window) == FALSE) return;
+
+/************************************************
+ * For all windows: save layers as undo layers  *
+ * and set current layer as new current object  *
+ *                                              *
+ * Modify listed objects and show error message *
+ * with objects that could not be modified      *
+ *                                              *
+ * For all windows: redraw gl_area image        *
+ ************************************************/
+
+gamgi_global_selection_undo ();
+gamgi_global_selection_focus ();
+
+start = NULL;
+for (dlist = gamgi->cells; dlist != NULL; dlist = dlist->next)
+  if (static_apply (GAMGI_CAST_GROUP dlist->data, window) == FALSE)
+    {
+    start = gamgi_engine_slist_add_start (start);
+    start->data = dlist->data;
+    }
+gamgi_io_error_list (start, window);
+
+gamgi_global_selection_draw ();
+
+/****************
+ * reset dialog *
+ ****************/
+
+static_reset (window);
+}
+
+static void static_ok_local (gamgi_window *window)
+{
+gamgi_group *group;
+GtkWidget *dialog = window->dialog0;
+gamgi_bool focus;
+
+cache.local = TRUE;
+
+/******************************************
+ * pick group and get name (possibly new) *
+ *                                        *
+ * check if focus object belongs to group *
+ ******************************************/
+
+cache.new[STATIC_NAME] = TRUE;
+group = GAMGI_CAST_GROUP gamgi_gtk_object_number (dialog,
+"entry_group", GAMGI_ENGINE_GROUP, window, cache.name);
+if (group == NULL)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid group identity", window);
+  return;
+  }
+
+focus = FALSE;
+if (gamgi_engine_find_object (window->focus,
+GAMGI_CAST_OBJECT group) == TRUE) focus = TRUE;
+
+/********************************************
+ * collect data from dialog and modify cell *
+ ********************************************/
+
+if (static_grab (window) == FALSE) return;
+if (static_apply (group, window) == FALSE) return;
+
+/*************************************************************
+ * when focus object is affected, change it to current layer *
+ *************************************************************/
+
+if (focus == TRUE)
+  gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
+
 /*****************************************
- * Redraw gl_area image and reset dialog *
+ * redraw gl_area image and reset dialog *
  *****************************************/
 
 gtk_widget_queue_draw (window->area);
 static_reset (window);
 }
 
-/******************* internal function *****************
- *                                                     *
- *                        STATIC_OK                    *
- *                                                     *
- * This is the function that actually creates a new    *
- * group. It is triggered when the user presses Ok.    *
- *                                                     *
- *******************************************************/
+/********************* internal function ******************
+ *                                                        *
+ *                         STATIC_OK                      *
+ *                                                        *
+ * This is the function that actually modifies a group or *
+ * list of groups, triggered when the user presses Ok.    *
+ **********************************************************/
 
 static void static_ok (GtkWidget *widget, void *data)
 {
-gamgi_group *group;
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *button;
-GtkWidget *combo;
-char token[GAMGI_ENGINE_TOKEN];
-int row;
+GtkWidget* button;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
-  {
-  /****************
-   * Local method *
-   ****************/
+/*********************************************
+ * modify data: execute global or local task *
+ *********************************************/
 
-  /**************************************
-   * Get name (possibly new) and number *
-   **************************************/
-
-  group = GAMGI_CAST_GROUP gamgi_gtk_object_number (dialog,
-  "entry_group", GAMGI_ENGINE_GROUP, window, token);
-  if (group == NULL)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid Group Object", window);
-    return;
-    }
-
-  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_type");
-  row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-  if (row == STATIC_TYPE_POLYTOPE ||
-  (row == STATIC_TYPE_LOCAL && group->type == GAMGI_CHEM_POLYTOPE))
-    static_ok_polytope (group, token, window);
-  else
-    static_ok_container (group, token, window);
-  }
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  static_ok_global (window);
+else
+  static_ok_local (window);
 }
 
 static void static_init (gamgi_window *window)
@@ -1177,7 +1447,7 @@ GtkWidget *button;
  * local mouse selection only *
  ******************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE ||
 window_dialog != window_mouse) return;
 
@@ -1243,11 +1513,11 @@ gtk_widget_show (hbox_left);
 
 hbox_left_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "hbox_group", hbox_left_left);
 gtk_widget_show (hbox_left_left);
 
 label = gtk_label_new ("Group");
 gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "label_group", label);
 gtk_widget_show (label);
 
 entry = gtk_entry_new ();
@@ -1257,15 +1527,15 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_group", entry);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
-button = gtk_toggle_button_new_with_label ("Global");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "toggled",
-G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
