@@ -677,7 +677,7 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Atom Create",
 static void static_interfaces_atom_copy (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Atom Copy",
-"interfaces/atom/copy", data, 1, 1);
+"interfaces/atom/copy", data, 2, 1, "copies", "shift");
 }
 
 static void static_interfaces_atom_select (void *data)
