@@ -27,6 +27,7 @@
 #include "gamgi_mesa_select.h"
 #include "gamgi_math_vector.h"
 #include "gamgi_io_token.h"
+#include "gamgi_io_error.h"
 #include "gamgi_global_selection.h"
 
 enum { STATIC_WINDOW, STATIC_LOCAL };
@@ -203,9 +204,10 @@ else
 static gamgi_bool static_grab (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
+GtkWidget *combo;
 GtkWidget *entry;
-GtkWidget *button;
 const char *name;
+int row;
 
 /********
  * name *
@@ -241,8 +243,9 @@ if (gamgi_io_token_int_scan (name, &cache.number, 1, INT_MAX) == FALSE)
  **********/
 
 cache.window = NULL;
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_window");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_location");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == STATIC_WINDOW)
   {
   cache.window = GAMGI_CAST_WINDOW gamgi_gtk_object_name_number (dialog,
   "entry_window", GAMGI_ENGINE_WINDOW, NULL);
@@ -331,6 +334,7 @@ static void static_ok_global (gamgi_window *window_dialog)
 gamgi_window *window_mouse;
 gamgi_object *object;
 gamgi_dlist *dlist;
+gamgi_slist *start;
 
 cache.local = FALSE;
 
@@ -348,8 +352,14 @@ if (static_grab (window_dialog) == FALSE) return;
  * copy layers according to dialog data *
  ****************************************/
 
+start = NULL;
 for (dlist = gamgi->layers; dlist != NULL; dlist = dlist->next)
-  static_apply (GAMGI_CAST_LAYER dlist->data, window_dialog);
+  if (static_apply (GAMGI_CAST_LAYER dlist->data, window_dialog) == FALSE)
+    {
+    start = gamgi_engine_slist_add_start (start);
+    start->data = dlist->data;
+    }
+gamgi_io_error_list (start, window_dialog);
 
 window_mouse = cache.window;
 if (window_mouse == NULL)
@@ -469,7 +479,8 @@ else
 static void static_init (gamgi_window *window)
 {
 static_reset (window);
-static_list (NULL, window);
+static_default_layer (window);
+static_default_window (window);
 }
 
 static void static_press (gamgi_object *object, void *data)
@@ -504,9 +515,11 @@ void gamgi_gtk_layer_copy_press (gamgi_window *window_mouse,
 GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 GtkWidget *dialog = window_dialog->dialog0;
+GtkWidget *combo;
 GtkWidget *button;
 GtkWidget *entry;
 const char *name;
+int row;
 
 /***********************************************
  * local location is active only in List mode, *
@@ -516,8 +529,9 @@ const char *name;
  * the location, the object to copy is local   *
  ***********************************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_local");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE) return;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_location");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == STATIC_LOCAL) return;
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_layer");
