@@ -191,9 +191,10 @@ else
 static gamgi_bool static_grab (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
+GtkWidget *combo;
 GtkWidget *entry;
-GtkWidget *button;
 const char *name;
+int row;
 
 /********
  * name *
@@ -229,8 +230,9 @@ if (gamgi_io_token_int_scan (name, &cache.number, 1, INT_MAX) == FALSE)
  *********/
 
 cache.layer = NULL;
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_layer");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_location");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == STATIC_LAYER)
   {
   cache.layer = GAMGI_CAST_LAYER gamgi_gtk_object_name_number (dialog,
   "entry_layer", GAMGI_ENGINE_LAYER, NULL);
@@ -531,9 +533,11 @@ void gamgi_gtk_light_copy_press (gamgi_window *window_mouse,
 GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 GtkWidget *dialog = window_dialog->dialog0;
+GtkWidget *combo;
 GtkWidget *button;
 GtkWidget *entry;
 const char *name;
+int row;
 
 /***********************************************
  * local location is active only in List mode, *
@@ -543,8 +547,9 @@ const char *name;
  * the location, the object to copy is local   *
  ***********************************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_local");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE) return;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_location");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == STATIC_LOCAL) return;
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_light");
