@@ -170,7 +170,7 @@ else
 
 }
 
-static void static_start_polygon (gamgi_window *window)
+static void static_start_scope (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *button_cell;
@@ -296,24 +296,24 @@ static void static_cell (GtkWidget *widget, void *data)
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 gamgi_cell *cell;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *vbox_polygon, *vbox_projection;
+GtkWidget *vbox_scope, *vbox_projection;
 
-vbox_polygon = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_polygon");
+vbox_scope = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_scope");
 vbox_projection = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_projection");
 
 cell = GAMGI_CAST_CELL gamgi_gtk_object_name_number (dialog,
 "entry_cell", GAMGI_ENGINE_CELL, window);
 if (cell != NULL && cell->type == GAMGI_PHYS_PROJECTION)
   {
-  gtk_widget_hide (vbox_polygon);
+  gtk_widget_hide (vbox_scope);
   gtk_widget_show (vbox_projection);
   static_start_projection (window);
   }
 else
   {
   gtk_widget_hide (vbox_projection);
-  gtk_widget_show (vbox_polygon);
-  static_start_polygon (window);
+  gtk_widget_show (vbox_scope);
+  static_start_scope (window);
   }
 }
 
@@ -582,7 +582,7 @@ if (gamgi_phys_plane_polygon (*atom1, *atom2, *atom3) == FALSE)
 return TRUE;
 }
 
-static gamgi_bool static_ok_polygon (gamgi_plane *plane, 
+static gamgi_bool static_ok_scope (gamgi_plane *plane, 
 gamgi_cell *cell, int *start, int *end, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
@@ -590,19 +590,14 @@ GtkWidget *entry;
 GtkWidget *combo;
 const char *name;
 int o1, o2, o3;
-int row;
 
-/***********************************
- * get type of plane link: the     *
- * default is GAMGI_MESA_AUTOMATIC *
- ***********************************/
+/*******************************
+ * get type of plane link: the *
+ * default is GAMGI_GTK_NONE   *
+ *******************************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
-if (row == GAMGI_GTK_ALL - 1) plane->autonomy = GAMGI_GTK_ALL;
-if (row == GAMGI_GTK_PARTIAL - 1) plane->autonomy = GAMGI_GTK_PARTIAL;
-if (row == GAMGI_GTK_NONE - 1) plane->autonomy = GAMGI_GTK_NONE;
+plane->autonomy = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 /**************************
  * get scanning thickness *
@@ -830,7 +825,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
     }
   else
     {
-    valid = static_ok_polygon (plane, cell, &start, &end, window);
+    valid = static_ok_scope (plane, cell, &start, &end, window);
     if (valid == FALSE) return;
     }
 
@@ -844,7 +839,7 @@ else
   valid = static_ok_atoms (plane, &atom1, &atom2, &atom3, window);
   if (valid == FALSE) return;
 
-  valid = static_ok_polygon (plane, NULL, &start, &end, window);
+  valid = static_ok_scope (plane, NULL, &start, &end, window);
   if (valid == FALSE) return;
   }
 
@@ -1437,15 +1432,15 @@ gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_object_set_data (G_OBJECT (dialog), "button_trace", button);
 gtk_widget_show (button);
 
-/****************
- * Polygon page *
- ****************/
+/**************
+ * Scope page *
+ **************/
  
 vbox_page = gtk_vbox_new (FALSE, 5);
-label = gtk_label_new ("Polygon");
+label = gtk_label_new (" Scope ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
 gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
-g_object_set_data (G_OBJECT (dialog), "vbox_polygon", vbox_page);
+g_object_set_data (G_OBJECT (dialog), "vbox_scope", vbox_page);
 gtk_widget_show (vbox_page);
 
 vbox_center = gtk_vbox_new (TRUE, 0);
