@@ -21,7 +21,7 @@ static void static_order_end (GtkWidget *widget, void *data);
 
 static void static_autonomy (GtkWidget *widget, void *data);
 
-static void static_start_polygon (gamgi_window *window);
+static void static_start_scope (gamgi_window *window);
 
 static void static_start_projection (gamgi_window *window);
 
@@ -44,7 +44,7 @@ static gamgi_bool static_ok_atoms (gamgi_plane *plane,
 gamgi_atom **atom1, gamgi_atom **atom2, gamgi_atom **atom3, 
 gamgi_window *window);
 
-static gamgi_bool static_ok_polygon (gamgi_plane *plane, gamgi_cell *cell, 
+static gamgi_bool static_ok_scope (gamgi_plane *plane, gamgi_cell *cell, 
 double *thickness, int *start, int *end, gamgi_window *window);
 
 static gamgi_bool static_ok_projection (gamgi_plane *plane, gamgi_bool *pole,
