@@ -271,7 +271,7 @@ int row;
  *********************************************************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_o4");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), FALSE);
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 7);
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o1");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
@@ -486,7 +486,7 @@ gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_GTK_ORDER - 1);
 static_instance (NULL, window);
 }
 
-static void static_start_polygon (gamgi_window *window)
+static void static_start_scope (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
@@ -560,7 +560,7 @@ int row;
  ******************************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_o4");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 7);
 
 /********************
  * get cell lattice *
@@ -591,9 +591,9 @@ static void static_cell (GtkWidget *widget, void *data)
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 gamgi_cell *cell;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *vbox_polygon, *vbox_projection;
+GtkWidget *vbox_scope, *vbox_projection;
 
-vbox_polygon = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_polygon");
+vbox_scope = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_scope");
 vbox_projection = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_projection");
 
 cell = GAMGI_CAST_CELL gamgi_gtk_object_name_number (dialog,
@@ -602,15 +602,15 @@ if (cell != NULL && cell->type == GAMGI_PHYS_PROJECTION)
   {
   if (gtk_widget_get_visible (vbox_projection) == FALSE)
     static_start_projection (window);
-  gtk_widget_hide (vbox_polygon);
+  gtk_widget_hide (vbox_scope);
   gtk_widget_show (vbox_projection);
   }
 else
   {
-  if (gtk_widget_get_visible (vbox_polygon) == FALSE)
-    static_start_polygon (window);
+  if (gtk_widget_get_visible (vbox_scope) == FALSE)
+    static_start_scope (window);
   gtk_widget_hide (vbox_projection);
-  gtk_widget_show (vbox_polygon);
+  gtk_widget_show (vbox_scope);
   }
 
 static_nodes (cell, window);
@@ -847,7 +847,7 @@ if (gamgi_phys_plane_polygon (*atom1, *atom2, *atom3) == FALSE)
 return TRUE;
 }
 
-static gamgi_bool static_ok_polygon (gamgi_cell *cell, int *hkl,
+static gamgi_bool static_ok_scope (gamgi_cell *cell, int *hkl,
 gamgi_enum vectors, gamgi_enum *type, gamgi_projection *projection,
 gamgi_enum *autonomy, double *thickness, int *order, gamgi_window *window)
 {
@@ -1327,7 +1327,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
       }
     else
       {
-      valid = static_ok_polygon (cell, hkl, vectors, 
+      valid = static_ok_scope (cell, hkl, vectors, 
       &type, &projection, &autonomy, &thickness, &order, window);
       if (valid == FALSE) return;
       }
@@ -1343,7 +1343,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
     valid = static_ok_atoms (plane, &atom1, &atom2, &atom3, &inside, window);
     if (valid == FALSE) return;
 
-    valid = static_ok_polygon (NULL, NULL, FALSE,
+    valid = static_ok_scope (NULL, NULL, FALSE,
     &type, &projection, &autonomy, &thickness, NULL, window);
     if (valid == FALSE) return;
     }
@@ -2222,15 +2222,15 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
-/****************
- * Polygon page *
- ****************/
+/**************
+ * Scope page *
+ **************/
  
 vbox_page = gtk_vbox_new (FALSE, 5);
-label = gtk_label_new ("Polygon");
+label = gtk_label_new (" Scope ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
 gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
-g_object_set_data (G_OBJECT (dialog), "vbox_polygon", vbox_page);
+g_object_set_data (G_OBJECT (dialog), "vbox_scope", vbox_page);
 gtk_widget_show (vbox_page);
 
 vbox_center = gtk_vbox_new (TRUE, 0);
@@ -2412,6 +2412,8 @@ gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "122", -1);
 gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "211", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Local", -1);
 gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
 g_object_unref (store);
 
@@ -2419,7 +2421,7 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
-sensitive = gamgi_gtk_dialog_sensitive_create (7);
+sensitive = gamgi_gtk_dialog_sensitive_create (8);
 g_object_set_data (G_OBJECT (dialog), "sensitive_o4", sensitive);
 gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (combo),
 renderer, gamgi_gtk_dialog_sensitive_scan, sensitive, free);
