@@ -11,6 +11,7 @@
 
 #include "gamgi_engine.h"
 #include "gamgi_gtk.h"
+#include "gamgi_global.h"
 
 #include "gamgi_engine_list.h"
 #include "gamgi_engine_find.h"
@@ -22,6 +23,7 @@
 #include "gamgi_gtk_object.h"
 #include "gamgi_mesa_select.h"
 #include "gamgi_io_token.h"
+#include "gamgi_global_selection.h"
 
 static void static_clean (gamgi_window *window)
 {
@@ -63,15 +65,15 @@ combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
-/********************* internal function ****************
- *                                                      *
- *                       STATIC_GLOBAL                  *
- *                                                      *
- * When the global button is on, disable the text entry *
- * and reset dialog, otherwise, enable the text entry.  *        
- ********************************************************/
+/********************* internal function ***************
+ *                                                     *
+ *                       STATIC_LIST                   *
+ *                                                     *
+ * When the List button is on, disable the text entry  *
+ * and reset dialog, otherwise, enable the text entry. *
+ *******************************************************/
 
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -79,7 +81,7 @@ GtkWidget *hbox;
 GtkWidget *button;
 
 hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_text");
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
@@ -100,13 +102,10 @@ else
   }
 }
 
-static void static_apply (gamgi_text *text, gamgi_window *window)
+static void static_apply (gamgi_text *text, int scope, gamgi_window *window)
 {
 gamgi_object *parent;
 gamgi_dlist *dlist;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *combo;
-int row;
 
 /**************************************************
  * Remove text data according to Scope combo box: *
@@ -116,14 +115,11 @@ int row;
  * 3) Contents: remove all child objects in text; *
  **************************************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
 /*****************************************
  * All: remove text and all its contents *
  *****************************************/
 
-if (row == 0)
+if (scope == 0)
   {
   gamgi_engine_unlink_text (text);
   gamgi_engine_remove_text (text);
@@ -133,7 +129,7 @@ if (row == 0)
  * Container: link contents to text parent and remove text *
  ***********************************************************/
 
-if (row == 1)
+if (scope == 1)
   {
   parent = text->object.object;
   gamgi_engine_reparent_text (text->text_start, parent);
@@ -145,7 +141,7 @@ if (row == 1)
  * Contents: remove all child objects in text *
  **********************************************/
 
-if (row == 2)
+if (scope == 2)
   {
   dlist = text->text_start;
   while (dlist != NULL)
@@ -157,57 +153,135 @@ if (row == 2)
 
 }
 
-static void static_ok (GtkWidget *widget, void *data)
+static void static_ok_global (int scope, gamgi_window *window)
+{
+gamgi_dlist *dlist, *texts;
+
+if (gamgi->texts == NULL)
+  { gamgi_gtk_dialog_message_create ("Error",
+  "Empty list of text objects", window); return; }
+
+/************************************************
+ * for all windows: save layers as undo layers, *
+ * set current layer as new current object      *
+ ************************************************/
+
+gamgi_global_selection_undo ();
+gamgi_global_selection_focus ();
+
+/*********************************************************
+ * disable automatic mechanism to remove selection list, *
+ * so we can scan the list and remove it only in the end *
+ *********************************************************/
+
+texts = gamgi->texts;
+gamgi->texts = NULL;
+
+/*******************************************************
+ *  remove text data as specified in scope combo box   * 
+ *                                                     *
+ * texts are recursive objects: a text may recursively *
+ * remove a child of the same class that appears later *
+ * in the list: listed objects that were already       *
+ * removed will have a list node pointing to NULL      *
+ *******************************************************/
+
+for (dlist = texts; dlist != NULL; dlist = dlist->next)
+  if (dlist->data != NULL)
+    static_apply (GAMGI_CAST_TEXT dlist->data, scope, window);
+
+/******************************************************
+ * remove the selection list of a class of objects    *
+ * only when objects of that class are really removed *
+ ******************************************************/
+
+gamgi->texts = texts;
+if (scope < 4)
+  gamgi_global_selection_remove (&gamgi->texts, "button_text");
+
+/*****************************************
+ * For all windows: redraw gl_area image *
+ *****************************************/
+
+gamgi_global_selection_draw ();
+}
+
+static void static_ok_local (int scope, gamgi_window *window)
 {
-gamgi_window *window = GAMGI_CAST_WINDOW data;
 gamgi_text *text;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *button;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
+/***************
+ * Pick object *
+ ***************/
+
+text = GAMGI_CAST_TEXT gamgi_gtk_object_name_number (dialog,
+"entry_text", GAMGI_ENGINE_TEXT, window);
+if (text == NULL)
   {
-  /***************
-   * Pick method *
-   ***************/
-
-  text = GAMGI_CAST_TEXT gamgi_gtk_object_name_number (dialog,
-  "entry_text", GAMGI_ENGINE_TEXT, window);
-  if (text == NULL)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid text object", window);
-    return;
-    }
-
-  /*************************************************
-   * Before removing the text, check if the        *
-   * current object is affected. In this case, the *
-   * current layer becomes the new current object. *
-   *************************************************/
-
-  if (gamgi_engine_find_object (window->focus,
-  GAMGI_CAST_OBJECT text) == TRUE)
-    gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
-
-  /***************************************
-   * Save current layer as undo buffer   *
-   * layer so it can be recovered later. *
-   ***************************************/
-
-  gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
-
-  /*************************************************
-   * remove text data as chosen in scope combo box *
-   *************************************************/
-
-  static_apply (text, window);
+  gamgi_gtk_dialog_message_create ("Error", "Invalid text object", window);
+  return;
   }
 
+/*************************************************
+ * Before removing the text, check if the        *
+ * current object is affected. In this case, the *
+ * current layer becomes the new current object. *
+ *************************************************/
+
+if (gamgi_engine_find_object (window->focus,
+GAMGI_CAST_OBJECT text) == TRUE)
+  gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
+
+/***************************************
+ * Save current layer as undo buffer   *
+ * layer so it can be recovered later. *
+ ***************************************/
+
+gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
+
+/*************************************************
+ * remove text data as chosen in scope combo box *
+ *************************************************/
+
+static_apply (text, scope, window);
+
 /*********************************************
  * Redraw gl_area image and reset text entry *
  *********************************************/
 
 gtk_widget_queue_draw (window->area);
+}
+
+static void static_ok (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *button;
+GtkWidget *combo;
+int scope;
+
+/*********************************************************
+ * get dialog data common to both local and global tasks *
+ *********************************************************/
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
+scope = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+
+/********************************
+ * execute global or local task *
+ ********************************/
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  static_ok_global (scope, window);
+else
+  static_ok_local (scope, window);
+
+/***********************************************************
+ * clean dialog data common to both local and global tasks *
+ ***********************************************************/
+
 static_clean (window);
 }
 
@@ -254,7 +328,7 @@ GtkWidget *button;
  * local mouse selection only *
  ******************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE ||
 window_dialog != window_mouse) return;
 
@@ -332,15 +406,15 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_text", entry);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
-button = gtk_toggle_button_new_with_label ("Global");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "toggled",
-G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
