@@ -57,12 +57,14 @@
 #include "gamgi_gtk_atom_modify.h"
 #include "gamgi_gtk_atom_measure.h"
 #include "gamgi_gtk_atom_remove.h"
+#include "gamgi_gtk_direction_copy.h"
 #include "gamgi_gtk_direction_create.h"
 #include "gamgi_gtk_direction_select.h"
 #include "gamgi_gtk_direction_link.h"
 #include "gamgi_gtk_direction_modify.h"
 #include "gamgi_gtk_direction_measure.h"
 #include "gamgi_gtk_direction_remove.h"
+#include "gamgi_gtk_plane_copy.h"
 #include "gamgi_gtk_plane_create.h"
 #include "gamgi_gtk_plane_select.h"
 #include "gamgi_gtk_plane_link.h"
@@ -139,6 +141,7 @@
 #include "gamgi_mesa_translate.h"
 #include "gamgi_mesa_rotate.h"
 #include "gamgi_mesa_scale.h"
+#include "gamgi_global_selection.h"
 
 static void static_menu_position (GtkMenu *menu,
 int *x, int *y, gamgi_bool *push, void *data)
@@ -1032,7 +1035,7 @@ g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_PLANE);
 g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", NULL, gamgi_gtk_plane_create, window);
-static_item_insert (menu, "Copy", "grey", gamgi_gtk_plane_copy, window);
+static_item_insert (menu, "Copy", NULL, gamgi_gtk_plane_copy, window);
 static_item_insert (menu, "Select", NULL, gamgi_gtk_plane_select, window);
 static_item_insert (menu, "Link", NULL, gamgi_gtk_plane_link, window);
 static_item_insert (menu, "Modify", NULL, gamgi_gtk_plane_modify, window);
@@ -1059,7 +1062,7 @@ g_object_set_data (G_OBJECT (menu), "select", (void *) GAMGI_ENGINE_DIRECTION);
 g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", NULL, gamgi_gtk_direction_create, window);
-static_item_insert (menu, "Copy", "grey", gamgi_gtk_direction_copy, window);
+static_item_insert (menu, "Copy", NULL, gamgi_gtk_direction_copy, window);
 static_item_insert (menu, "Select", NULL, gamgi_gtk_direction_select, window);
 static_item_insert (menu, "Link", NULL, gamgi_gtk_direction_link, window);
 static_item_insert (menu, "Modify", NULL, gamgi_gtk_direction_modify, window);
@@ -1342,18 +1345,21 @@ gamgi_gtk_statusbar_time_timeout (NULL);
 gamgi_gtk_object_layer_local (layer, window);
 gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT layer, window);
 
-/********************************************************************
- * show and raise new window to the top, hide main,tool,status bars *
- ********************************************************************/
+/***********************************************************
+ * 1) show and raise new window to the top; 2) hide        *
+ * main,tool,status bars; 3) update top menu label colors, *
+ * to indicate which objects have lists currently active   *
+ ***********************************************************/
  
 gtk_widget_show (window->window);
-
 drawable = gtk_widget_get_window (window->window);
 gdk_window_raise (drawable);
 
 if (window->top_flag == FALSE) gtk_widget_hide (window->top);
 if (window->medium_flag == FALSE) gtk_widget_hide (window->medium);
 if (window->bottom_flag == FALSE) gtk_widget_hide (window->bottom);
+
+gamgi_global_selection_update_objects (window);
 }
 
 void gamgi_gtk_window_create_menus (gamgi_window *window)
