@@ -14,81 +14,111 @@
 #include "gamgi_io.h"
 #include "gamgi_global.h"
 
+#include "gamgi_engine_list.h"
+#include "gamgi_engine_link.h"
+#include "gamgi_engine_unlink.h"
+#include "gamgi_engine_copy.h"
 #include "gamgi_engine_find.h"
 #include "gamgi_engine_empty.h"
+#include "gamgi_engine_remove.h"
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_gtk_object.h"
+#include "gamgi_gtk_history.h"
 #include "gamgi_gtk_window_remove.h"
 #include "gamgi_mesa_select.h"
+#include "gamgi_mesa_translate.h"
 #include "gamgi_io_token.h"
+#include "gamgi_io_error.h"
+#include "gamgi_global_selection.h"
+
+enum { STATIC_OBJECT, STATIC_ALL };
+
+static struct {
+gamgi_bool local;
+gamgi_enum method;
+gamgi_object *object;
+gamgi_bool above;
+double origin[3]; } cache;
 
 static gamgi_enum static_class (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
 GtkWidget *button;
+GtkWidget *combo;
 const char *name;
+int row;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+/**********************************************************
+ * All mode: look for a window                            *
+ * Object mode: look first for a window, then for a layer *
+ **********************************************************/
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_method");
+row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (row == STATIC_ALL) return GAMGI_ENGINE_WINDOW;
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_window");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-
-/*********************************************
- * when entries are empty, look for a window *
- *********************************************/
-
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE &&
 gamgi_io_token_check (name) == FALSE) return GAMGI_ENGINE_WINDOW;
 
-/****************************
- * otherwise return a layer *
- ****************************/
-
 return GAMGI_ENGINE_LAYER;
 }
 
+static void static_default_window (gamgi_window *window)
+{
+gamgi_object *object;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+char string[GAMGI_ENGINE_STRING];
+
+object = GAMGI_CAST_OBJECT window;
+sprintf (string, "%s %d", object->name, object->number);
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_window");
+gtk_entry_set_text (GTK_ENTRY (entry), string);
+}
+
 static void static_method (GtkWidget *widget, void *data)
 {
-gamgi_window *window_dialog = GAMGI_CAST_WINDOW data;
-gamgi_window *window_mouse;
-GtkWidget *dialog = window_dialog->dialog0;
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *vbox;
 GtkWidget *entry;
+GtkWidget *hbox;
 GtkWidget *combo;
-char string[2 * GAMGI_ENGINE_TOKEN];
 int row;
 
-/***************************************************************
- * window_mouse is the window where the user presses the mouse *
- * window_dialog is the window where the dialog window is open *
- ***************************************************************/
+/************
+ * get data *
+ ************/
 
-/*********************
- * reset layer entry *
- *********************/
- 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_layer");
-gtk_entry_set_text (GTK_ENTRY (entry), "");
-
-/**********************
- * get link combo box *
- **********************/
+hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_object");
+vbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_shift");
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_method");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
-/***************************************************
- * The selected window collects all the non-empty  *
- * layers. By default, the selected window current *
- * layer will remain the current layer in the end. *
- ***************************************************/
-
-window_mouse = GAMGI_CAST_WINDOW gamgi_gtk_object_name_number (dialog,
-"entry_window", GAMGI_ENGINE_WINDOW, window_dialog);
-if (window_mouse != NULL && row == 1)
+switch (row)
   {
-  sprintf (string, "%s %d", window_mouse->layer->object.name, 
-  window_mouse->layer->object.number);
-  gtk_entry_set_text (GTK_ENTRY (entry), string);
+  /***************************************************
+   * The selected window collects all the non-empty  *
+   * layers. By default, the selected window current *
+   * layer will remain the current layer in the end. *
+   ***************************************************/
+
+  case STATIC_ALL:
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_object");
+  gtk_entry_set_text (GTK_ENTRY (entry), "");
+  gtk_widget_set_sensitive (hbox, FALSE);
+  gtk_widget_hide (vbox);
+  break;
+
+  case STATIC_OBJECT: default:
+  gtk_widget_set_sensitive (hbox, TRUE);
+  gtk_widget_show (vbox);
+  break;
   }
 
 }
@@ -105,6 +135,8 @@ static void static_reset (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
+GtkWidget *combo;
+char token[GAMGI_ENGINE_TOKEN];
 
 /**************************
  * reset window and layer *
@@ -113,8 +145,23 @@ GtkWidget *entry;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_window");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_layer");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_object");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_method");
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_OBJECT);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
+sprintf (token, "%f", GAMGI_GTK_LINK_X);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
+sprintf (token, "%f", GAMGI_GTK_LINK_Y);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
+sprintf (token, "%f", GAMGI_GTK_LINK_Z);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
 }
 
 static void static_clean (gamgi_window *window)
@@ -126,7 +173,7 @@ GtkWidget *entry;
  * keep window, reset object *
  *****************************/
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_layer");
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_object");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
 }
 
@@ -145,10 +192,11 @@ static void static_list (GtkWidget *widget, void *data)
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
 GtkWidget *hbox, *button;
+gamgi_bool *sensitive;
 
+sensitive = (gamgi_bool *) g_object_get_data (G_OBJECT (dialog), "sensitive_method");
 hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_window");
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
-
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
   /******************************
@@ -156,6 +204,8 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
    ******************************/
 
   gtk_widget_set_sensitive (hbox, TRUE);
+  sensitive[STATIC_ALL] = TRUE;
+  static_default_window (window);
   }
 else
   {
@@ -164,28 +214,121 @@ else
    ******************************************/
 
   static_reset (window);
+  sensitive[STATIC_ALL] = FALSE;
   gtk_widget_set_sensitive (hbox, FALSE);
   }
 }
 
-static void static_object (gamgi_window *window_mouse, 
-gamgi_layer *layer, gamgi_window *window_dialog)
+static void static_origin (gamgi_object *child)
 {
-/******************************************************
- * window_mouse is the selected window, window_dialog *
- * is the window where the dialog was opened          *
- ******************************************************/
+/*****************************************************
+ * translation is always applied to the object below *
+ *****************************************************/
 
-gamgi_gtk_object_link (GAMGI_CAST_OBJECT layer, 
-GAMGI_CAST_OBJECT window_mouse, window_dialog);
-
-static_clean (window_dialog);
+gamgi_mesa_translate_object (child, cache.origin);
 }
 
-static void static_all (gamgi_window *window_mouse,
-gamgi_layer *layer, gamgi_window *window_dialog)
+static gamgi_bool static_grab (gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+GtkWidget *combo;
+const char *name;
+
+/************************
+ * get link option menu *
+ ************************/
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_method");
+cache.method = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (cache.method == STATIC_ALL) return TRUE;
+
+/********************
+ * get global layer *
+ ********************/
+
+cache.object = gamgi_gtk_object_name_number (dialog,
+"entry_object", static_class (window), NULL);
+if (cache.object == NULL )
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid layer object", window);
+  return FALSE;
+  }
+
+/*********************
+ * x,y,z coordinates *
+ *********************/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_double_scan (name, &cache.origin[0], -DBL_MAX, DBL_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid position data", window);
+  return FALSE;
+  }
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_double_scan (name, &cache.origin[1], -DBL_MAX, DBL_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid position data", window);
+  return FALSE;
+  }
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_double_scan (name, &cache.origin[2], -DBL_MAX, DBL_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid position data", window);
+  return FALSE;
+  }
+
+return TRUE;
+}
+
+static gamgi_bool static_apply (gamgi_object *child,
+gamgi_object *parent, gamgi_window *window_dialog)
+{
+/********************************************
+ * check if child already belongs to parent *
+ ********************************************/
+
+if (child->object == parent)
+  {
+  if (cache.local == TRUE)
+    gamgi_gtk_dialog_message_create ("Error",
+    "Child already linked to parent", window_dialog);
+  return FALSE;
+  }
+
+if (cache.local == FALSE)
+  {
+  /***************************************************************
+   * get new equivalent layer and start undo and save mechanisms *
+   ***************************************************************/
+
+  child = gamgi_engine_copy_object (child);
+  gamgi_gtk_history_start (GAMGI_CAST_LAYER child);
+  }
+else
+  gamgi_engine_unlink_object (child);
+
+gamgi_engine_link_object_object (child, parent);
+
+/**************************
+ * translate child object *
+ **************************/
+
+static_origin (child);
+
+return TRUE;
+}
+
+static void static_ok_all (gamgi_window *window_mouse,
+gamgi_window *window_dialog)
 {
 gamgi_window *window;
+gamgi_layer *layer;
 gamgi_dlist *dlist;
 
 /***************************************************************
@@ -208,107 +351,228 @@ for (window = gamgi->window_start; window != NULL; window = window->next)
     layer = GAMGI_CAST_LAYER dlist->data;
     dlist = dlist->next;
 
+    /*************************************
+     * If layer is current layer, then a *
+     *  new current layer must be found. *
+     *************************************/
+
     if (gamgi_engine_empty_layer (layer) == TRUE) continue;
-    gamgi_gtk_object_link (GAMGI_CAST_OBJECT layer, 
-    GAMGI_CAST_OBJECT window_mouse, window_dialog);
+
+    if (layer == window->layer)
+      gamgi_gtk_object_layer_current (layer, window);
+
+    gamgi_engine_unlink_layer (layer);
+    gamgi_engine_link_layer_window (layer, window_mouse);
+    window_mouse->layer = layer;
     }
     while (dlist != NULL);
   }
 
+/********************************
+ * remove all the other windows *
+ ********************************/
+
 for (window = gamgi->window_start; window != NULL; window = window->next)
   if (window != window_mouse) gamgi_gtk_window_remove_apply (window);
 
+/********************************************************
+ * the last layer linked (or the old one, when no layer *
+ * was linked) becomes the new current layer and object *
+ ********************************************************/
+
+gamgi_gtk_object_layer_local (window_mouse->layer, window_mouse);
+gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window_mouse->layer, window_mouse);
+
+/*****************************************************
+ * redraw window_mouse drawing area and close dialog *
+ *****************************************************/
+
+gtk_widget_queue_draw (window_mouse->area);
+
 gamgi_gtk_dialog_task0_remove (NULL, window_dialog);
 }
 
-static void static_ok (GtkWidget *widget, void *data)
+static void static_ok_global (gamgi_window *window_dialog)
 {
-gamgi_window *window_dialog = GAMGI_CAST_WINDOW data;
-gamgi_window *window_mouse;
+gamgi_object *child, *parent;
+gamgi_dlist *dlist;
+gamgi_slist *start;
+
+cache.local = FALSE;
+
+/*******************
+ * get window list *
+ *******************/
+
+if (gamgi->windows == NULL)
+  { gamgi_gtk_dialog_message_create ("Error",
+  "Empty list of window objects", window_dialog); return; }
+
+if (static_grab (window_dialog) == FALSE) return;
+
+/**********************************************
+ * Link listed objects and show error message *
+ * with objects that could not be linked      *
+ *                                            *
+ *      For all windows: set last layer       *
+ *      as new current object and layer       *
+ *                                            *
+ *   For all windows: redraw gl_area image    *
+ **********************************************/
+
+/*****************************************
+ * link each window of the list to a new *
+ * layer copied from the selected layer  *
+ *****************************************/
+
+child = cache.object;
+
+start = NULL;
+for (dlist = gamgi->windows; dlist != NULL; dlist = dlist->next)
+  {
+  parent = GAMGI_CAST_OBJECT dlist->data;
+
+  if (static_apply (child, parent, window_dialog) == FALSE)
+    {
+    start = gamgi_engine_slist_add_start (start);
+    start->data = dlist->data;
+    }
+  }
+gamgi_io_error_list (start, window_dialog);
+
+/************************************************************
+ * for all windows: 1) last layer becomes current layer;    *
+ * 2) current layer becomes current object; 3) redraw image *
+ ************************************************************/
+
+gamgi_global_selection_layer ();
+gamgi_global_selection_focus ();
+gamgi_global_selection_draw ();
+
+/****************
+ * reset dialog *
+ ****************/
+
+static_reset (window_dialog);
+}
+
+static void static_ok_local (gamgi_window *window_dialog)
+{
+gamgi_window *window_mouse, *window_old;
 gamgi_layer *layer;
 GtkWidget *dialog = window_dialog->dialog0;
-GtkWidget *combo;
-int row;
 
-/***************************************************************
- * window_mouse is the window where the user presses the mouse *
- * window_dialog is the window where the dialog window is open *
- ***************************************************************/
+cache.local = TRUE;
 
-/**************
- * get window *
- **************/
+/********************************
+ * pick window, get dialog data *
+ ********************************/
 
 window_mouse = GAMGI_CAST_WINDOW gamgi_gtk_object_name_number (dialog,
 "entry_window", GAMGI_ENGINE_WINDOW, window_dialog);
 if (window_mouse == NULL)
   {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid Window", window_dialog);
+  gamgi_gtk_dialog_message_create ("Error",
+  "Invalid window object", window_dialog);
   return;
   }
 
-/*************
- * get layer *
- *************/
+/********************
+ * grab dialog data *
+ ********************/
 
-layer = GAMGI_CAST_LAYER gamgi_gtk_object_name_number (dialog, 
-"entry_layer", GAMGI_ENGINE_LAYER, NULL);
-if (layer == NULL)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid Layer", window_dialog);
-  return;
-  }
+if (static_grab (window_dialog) == FALSE) return;
 
-/************************
- * get link option menu *
- ************************/
+/*************************************************
+ * method ALL: move all non-empty layers to      *
+ * current window, then remove the other windows *
+ *************************************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_method");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (cache.method == STATIC_ALL)
+  { static_ok_all (window_mouse, window_dialog); return; }
 
-/************
- * get data *
- ************/
+/**************************************************************
+ * method OBJECT: link window to global layer below. If layer *
+ * is current layer, then a  new current layer must be found. *
+ **************************************************************/
 
-if (row == 0) static_object (window_mouse, layer, window_dialog);
-if (row == 1) static_all (window_mouse, layer, window_dialog);
+layer = GAMGI_CAST_LAYER cache.object;
+window_old = GAMGI_CAST_WINDOW layer->object.object;
+if (layer == window_old->layer)
+  gamgi_gtk_object_layer_current (layer, window_old);
+
+static_apply (cache.object, GAMGI_CAST_OBJECT window_mouse, window_dialog);
+
+/********************************************************
+ * raise to top window and layer where parent object is *
+ ********************************************************/
+
+gamgi_gtk_object_raise (layer, window_mouse);
+
+/***********************************************
+ * redraw drawing area for new and old windows *
+ ***********************************************/
+
+gtk_widget_queue_draw (window_mouse->area);
+gtk_widget_queue_draw (window_old->area);
+
+static_clean (window_dialog);
+}
+
+static void static_ok (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget* button;
+
+/*******************************************
+ * link data: execute global or local task *
+ *******************************************/
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  static_ok_global (window);
+else
+  static_ok_local (window);
 }
 
 static void static_init (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
-GtkWidget *entry;
-GtkWidget *combo;
-char string[2 * GAMGI_ENGINE_TOKEN];
+GtkWidget *notebook;
+GtkRequisition size;
 
-/*****************************
- * start with current window *
- *****************************/
+/***************************************************
+ * Set notebook current size as its maximum size:  *
+ * this is needed because pages are shown/hidden,  *
+ * changing the currently needed size for dialog.  *
+ * Fixing the dialog size only partly solves the   *
+ * problem because the page size can still change. *
+ ***************************************************/
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_window");
-sprintf (string, "%s %d", window->object.name, window->object.number);
-gtk_entry_set_text (GTK_ENTRY (entry), string);
+notebook = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "notebook");
+gtk_widget_size_request (GTK_WIDGET (notebook), &size);
+gtk_widget_set_size_request (notebook, size.width, size.height);
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_method");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+/********************************************
+ * hide pages AFTER measuring notebook size *
+ ********************************************/
+
+static_reset (window);
+static_default_window (window);
 }
 
 static void static_press (gamgi_object *object, void *data)
 {
 gamgi_window *window_dialog = gamgi->window_dialog;
 GtkWidget *dialog = window_dialog->dialog0;
-GtkWidget *button;
 GtkWidget *entry;
-char string[2 * GAMGI_ENGINE_TOKEN];
-const char *name;
+char string[GAMGI_ENGINE_STRING];
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_window");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE ||
-gamgi_io_token_check (name) == TRUE)
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_layer");
+if (static_class (window_dialog) == GAMGI_ENGINE_WINDOW)
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_window");
+else
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_object");
 
 sprintf (string, "%s %d", object->name, object->number);
 gtk_entry_set_text (GTK_ENTRY (entry), string);
@@ -333,7 +597,7 @@ const char *name;
  * the second object, not the main object(s)   *
  ***********************************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_window");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
@@ -366,12 +630,14 @@ GtkWidget *notebook;
 GtkWidget *button;
 GtkWidget *label;
 GtkWidget *entry;
+GtkWidget *table;
 GtkWidget *hbox_center, *hbox_left, *hbox_left_left;
 GtkWidget *vbox_dialog, *vbox_page, *vbox_center, *vbox_top;
 GtkWidget *combo;
 GtkListStore *store;
 GtkCellRenderer *renderer;
 GtkTreeIter iter;
+gamgi_bool *sensitive;
 
 /******************
  * dialog level 0 *
@@ -421,14 +687,14 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_window", entry);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
-button = gtk_toggle_button_new_with_label ("Global");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "toggled", G_CALLBACK (static_list), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
@@ -441,9 +707,9 @@ gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
 g_object_set_data (G_OBJECT (dialog), "notebook", notebook);
 gtk_widget_show (notebook);
 
-/**************
- * layer page *
- **************/
+/***************
+ * Object page *
+ ***************/
 
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Object");
@@ -459,9 +725,9 @@ vbox_top = gtk_vbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
-/*********
- * layer *
- *********/
+/*****************
+ * Object: Layer *
+ *****************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
@@ -469,6 +735,7 @@ gtk_widget_show (hbox_center);
 
 hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "hbox_object", hbox_left);
 gtk_widget_show (hbox_left);
 
 label = gtk_label_new ("Layer");
@@ -479,7 +746,7 @@ entry = gtk_entry_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0); 
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
-g_object_set_data (G_OBJECT (dialog), "entry_layer", entry);
+g_object_set_data (G_OBJECT (dialog), "entry_object", entry);
 gtk_widget_show (entry);
 
 /**********
@@ -516,6 +783,75 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
+sensitive = gamgi_gtk_dialog_sensitive_create (2);
+g_object_set_data (G_OBJECT (dialog), "sensitive_method", sensitive);
+gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (combo),
+renderer, gamgi_gtk_dialog_sensitive_scan, sensitive, free);
+
+/**************
+ * Shift page *
+ **************/
+
+vbox_page = gtk_vbox_new (FALSE, 5);
+label = gtk_label_new (" Shift ");
+gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
+g_object_set_data (G_OBJECT (dialog), "vbox_shift", vbox_page);
+gtk_widget_show (vbox_page);
+
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
+
+vbox_top = gtk_vbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top);
+
+/*********************
+ * x,y,z coordinates *
+ *********************/
+
+hbox_center = gtk_hbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
+gtk_widget_show (hbox_center);
+
+table = gtk_table_new (1, 6, FALSE);
+gtk_box_pack_start (GTK_BOX (hbox_center), table, FALSE, FALSE, 5);
+gtk_widget_show (table);
+
+label = gtk_label_new ("X");
+gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+gtk_widget_show (label);
+
+label = gtk_label_new ("Y");
+gtk_table_attach (GTK_TABLE (table), label, 3, 4, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+gtk_widget_show (label);
+
+label = gtk_label_new ("Z");
+gtk_table_attach (GTK_TABLE (table), label, 5, 6, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+gtk_widget_show (label);
+
+entry = gtk_entry_new ();
+gtk_table_attach (GTK_TABLE (table), entry, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+g_object_set_data (G_OBJECT (dialog), "entry_x", entry);
+gtk_widget_show (entry);
+
+entry = gtk_entry_new ();
+gtk_table_attach (GTK_TABLE (table), entry, 2, 3, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+g_object_set_data (G_OBJECT (dialog), "entry_y", entry);
+gtk_widget_show (entry);
+
+entry = gtk_entry_new ();
+gtk_table_attach (GTK_TABLE (table), entry, 4, 5, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+g_object_set_data (G_OBJECT (dialog), "entry_z", entry);
+gtk_widget_show (entry);
+
 /*********************
  * Ok/Cancel buttons *
  *********************/
