@@ -101,8 +101,8 @@ GAMGI_IO_DEJAVU_MONO_ITALIC, GAMGI_IO_DEJAVU_MONO_BOLD_ITALIC };
  * the Gamgi->About GUI dialog *
  *******************************/
 
-#define GAMGI_IO_DATE "20th September 2010"
-#define GAMGI_IO_VERSION "0.14.10"
+#define GAMGI_IO_DATE "26th October 2010"
+#define GAMGI_IO_VERSION "0.14.11"
 #define GAMGI_IO_AUTHORS "Carlos Pereira et al."
 #define GAMGI_IO_LICENSE "GPL"
 #define GAMGI_IO_WEBSITE "http://www.gamgi.org/"
