@@ -57,6 +57,10 @@ enum { GAMGI_MESA_DIRECTIONAL = 1, GAMGI_MESA_POSITIONAL, GAMGI_MESA_SPOT };
 
 enum { GAMGI_MESA_MASK_CROSS = 1, GAMGI_MESA_MASK_CHESS };
 
+enum { GAMGI_MESA_SELECT_READY = 1, GAMGI_MESA_SELECT_SIZE,
+GAMGI_MESA_SELECT_DONE, GAMGI_MESA_SELECT_MOVE,
+GAMGI_MESA_SELECT_RESIZE };
+
 /************* macros ************
  *********************************/
 
@@ -86,6 +90,13 @@ enum { GAMGI_MESA_MASK_CROSS = 1, GAMGI_MESA_MASK_CHESS };
 #define GAMGI_MESA_MOVE_SPEED    40.0
 #define GAMGI_MESA_SCALE_SPEED   10.0
 
+/***************************************************
+ * width used to draw wired and solid polyhedrons, *
+ * such as Voronoi clusters and Polytope groups    *
+ ***************************************************/
+
+#define GAMGI_MESA_POLYHEDRON_WIDTH 1.0
+
 /******************************
  * layer modelview parameters *
  ******************************/
@@ -131,7 +142,16 @@ enum { GAMGI_MESA_MASK_CROSS = 1, GAMGI_MESA_MASK_CHESS };
  * draw translucid layers  *
  ***************************/
 
-#define GAMGI_MESA_LAYER_BLENDING 0.2
+#define GAMGI_MESA_LAYER_BLEND 0.25
+
+/**************************************************************
+ * the rectangle used to select visible objects by region:    *
+ * the size of the move, resize little squares at the corners *
+ * the blending factor used outside the selection rectangle   *
+ **************************************************************/
+
+#define GAMGI_MESA_SELECT_SQUARE  20
+#define GAMGI_MESA_SELECT_BLEND 0.50
 
 /***********************
  * default layer color *
@@ -187,9 +207,9 @@ enum { GAMGI_MESA_MASK_CROSS = 1, GAMGI_MESA_MASK_CHESS };
  * pattern; 3) around spherical volumes in cells.    *
  *****************************************************/
 
-#define GAMGI_MESA_CELL_WIDTH 1.0
-#define GAMGI_MESA_CELL_POINT 3.0
-#define GAMGI_MESA_CELL_SLICES 64
+#define GAMGI_MESA_CELL_WIDTH  1.0
+#define GAMGI_MESA_CELL_POINT  3.0
+#define GAMGI_MESA_CELL_SLICES 100
 
 /**********************
  * default cell color *
@@ -210,20 +230,22 @@ enum { GAMGI_MESA_MASK_CROSS = 1, GAMGI_MESA_MASK_CHESS };
 #define GAMGI_MESA_CELL_RECIPROCAL_G 0.5
 #define GAMGI_MESA_CELL_RECIPROCAL_B 1.0
 
-/*******************************************************
- * width used to draw wired and solid Voronoi clusters *
- *******************************************************/
-
-#define GAMGI_MESA_CLUSTER_WIDTH 2.0
-
 /**************************************
- * default color for Voronoi clusters *
+ * default color for Voronoi Clusters *
  **************************************/
 
 #define GAMGI_MESA_CLUSTER_R 1.0
 #define GAMGI_MESA_CLUSTER_G 1.0
 #define GAMGI_MESA_CLUSTER_B 1.0
 
+/**************************************
+ * default color for Polytope Groups *
+ **************************************/
+
+#define GAMGI_MESA_GROUP_R 0.0
+#define GAMGI_MESA_GROUP_G 1.0
+#define GAMGI_MESA_GROUP_B 1.0
+
 /*************************************************
  * width used to render Plane, Direction objects *
  * as cross, chess bitmap masks in Stereographic *
@@ -238,7 +260,7 @@ enum { GAMGI_MESA_MASK_CROSS = 1, GAMGI_MESA_MASK_CHESS };
  * and plane polygons in sphere volumes *
  ****************************************/
 
-#define GAMGI_MESA_PLANE_SLICES 128
+#define GAMGI_MESA_PLANE_SLICES 100
 
 /***********************
  * default plane color *
@@ -266,7 +288,7 @@ enum { GAMGI_MESA_MASK_CROSS = 1, GAMGI_MESA_MASK_CHESS };
 #define GAMGI_MESA_ATOM_WIDTH 2
 
 #define GAMGI_MESA_ATOM_SLICES_MIN 4
-#define GAMGI_MESA_ATOM_SLICES_MAX 64
+#define GAMGI_MESA_ATOM_SLICES_MAX 100
 #define GAMGI_MESA_ATOM_SLICES 16
 
 /*****************************************
