@@ -1015,13 +1015,17 @@ glEnable ((GLenum) GL_LIGHT0 + offset);
 void gamgi_mesa_draw_layer (gamgi_layer *layer, gamgi_window *window) 
 {
 gamgi_dlist *dlist;
-int light;
-float width = window->area->allocation.width;
-float height = window->area->allocation.height;
-float aspect = width/height;
+GtkAllocation allocation;
+float width, height, aspect;
 float top = layer->top;
 float off[4] = {0.0, 0.0, 0.0, 1.0};
 float on[4] = {1.0, 1.0, 1.0, 1.0};
+int light;
+
+gtk_widget_get_allocation (window->area, &allocation);
+width = allocation.width;
+height = allocation.height;
+aspect = width / height;
 
 /************************
  * restart depth buffer *
@@ -1212,6 +1216,7 @@ void gamgi_mesa_draw_window (gamgi_window *window)
 {
 gamgi_dlist *dlist;
 gamgi_layer *layer;
+GtkAllocation allocation;
 int x, y;
 
 /************************************************************
@@ -1270,8 +1275,9 @@ if (window->layer->visibility_out != GAMGI_GTK_NONE)
   window->layer->color[2], GAMGI_MESA_LAYER_BLEND);
   
   glClear (GL_DEPTH_BUFFER_BIT);
-  x = window->area->allocation.width;
-  y = window->area->allocation.height;
+  gtk_widget_get_allocation (window->area, &allocation);
+  x = allocation.width;
+  y = allocation.height;
 
   glBegin (GL_POLYGON);
   glVertex3f (-x, -y, 0.0);
