@@ -41,9 +41,8 @@ enum { GAMGI_PHYS_CUTOFF_OBJECTS = 1, GAMGI_PHYS_CUTOFF_NODES };
 
 enum { GAMGI_PHYS_WULFF = 1, GAMGI_PHYS_SCHMIDT };
 
-enum { GAMGI_PHYS_NODE_011 = 1, GAMGI_PHYS_NODE_101,
-GAMGI_PHYS_NODE_110, GAMGI_PHYS_NODE_111, GAMGI_PHYS_NODE_122,
-GAMGI_PHYS_NODE_211 };
+enum { GAMGI_PHYS_011 = 1, GAMGI_PHYS_101, GAMGI_PHYS_110,
+GAMGI_PHYS_111, GAMGI_PHYS_122, GAMGI_PHYS_211 };
 
 /************* macros ************
  *********************************/
@@ -89,9 +88,9 @@ GAMGI_PHYS_NODE_211 };
 #define GAMGI_PHYS_CELL_O2 0
 #define GAMGI_PHYS_CELL_O3 0
 
-/****************************
- * default node coordinates *
- ****************************/
+/*******************************
+ * default Wyckoff coordinates *
+ *******************************/
 
 #define GAMGI_PHYS_NODE_X 0.0
 #define GAMGI_PHYS_NODE_Y 0.0
@@ -188,9 +187,9 @@ GAMGI_PHYS_NODE_211 };
 #define GAMGI_PHYS_PLANE_RANGE_START 1
 #define GAMGI_PHYS_PLANE_RANGE_END   1
 
-#define GAMGI_PHYS_DIRECTION_NODE_O1 0
-#define GAMGI_PHYS_DIRECTION_NODE_O2 0
-#define GAMGI_PHYS_DIRECTION_NODE_O3 0
+#define GAMGI_PHYS_NODE_O1 0
+#define GAMGI_PHYS_NODE_O2 0
+#define GAMGI_PHYS_NODE_O3 0
 
 /*************************************************
  * Default range of Directions used to represent *
