@@ -661,7 +661,7 @@ cell->lattice == GAMGI_PHYS_ORTHORHOMBIC_I)
   offset[0] = 2 * o1;
   offset[1] = 2 * o2;
   offset[2] = 2 * o3;
-  if (o4 == GAMGI_PHYS_NODE_111)
+  if (o4 == GAMGI_PHYS_111)
      { offset[0] += 1; offset[1] += 1; offset[2] += 1; }
   return;
   }
@@ -672,9 +672,9 @@ cell->lattice == GAMGI_PHYS_ORTHORHOMBIC_F)
   offset[0] = 2 * o1;
   offset[1] = 2 * o2;
   offset[2] = 2 * o3;
-  if (o4 == GAMGI_PHYS_NODE_110) { offset[0] += 1; offset[1] += 1; }
-  if (o4 == GAMGI_PHYS_NODE_101) { offset[0] += 1; offset[2] += 1; }
-  if (o4 == GAMGI_PHYS_NODE_011) { offset[1] += 1; offset[2] += 1; }
+  if (o4 == GAMGI_PHYS_110) { offset[0] += 1; offset[1] += 1; }
+  if (o4 == GAMGI_PHYS_101) { offset[0] += 1; offset[2] += 1; }
+  if (o4 == GAMGI_PHYS_011) { offset[1] += 1; offset[2] += 1; }
   return;
   }
 
@@ -684,7 +684,7 @@ cell->lattice == GAMGI_PHYS_MONOCLINIC_C)
   offset[0] = 2 * o1;
   offset[1] = 2 * o2;
   offset[2] = o3;
-  if (o4 == GAMGI_PHYS_NODE_110) { offset[0] += 1; offset[1] += 1; }
+  if (o4 == GAMGI_PHYS_110) { offset[0] += 1; offset[1] += 1; }
   return;
   }
 
@@ -698,7 +698,7 @@ if (cell->lattice == GAMGI_PHYS_TETRAGONAL_I)
   offset[0] = o1 - o2;
   offset[1] = o1 + o2;
   offset[2] = 2 * o3;
-  if (o4 == GAMGI_PHYS_NODE_111) { offset[1] += 1; offset[2] += 1; }
+  if (o4 == GAMGI_PHYS_111) { offset[1] += 1; offset[2] += 1; }
   return;
   }
 
@@ -711,8 +711,8 @@ if (cell->lattice == GAMGI_PHYS_HEXAGONAL_R)
   offset[0] = 2 * o1 - o2;
   offset[1] = 2 * o2 - o1;
   offset[2] = 3 * o3;
-  if (o4 == GAMGI_PHYS_NODE_211) { offset[0] += 1; offset[2] += 1; }
-  if (o4 == GAMGI_PHYS_NODE_122) { offset[1] += 1; offset[2] += 2; }
+  if (o4 == GAMGI_PHYS_211) { offset[0] += 1; offset[2] += 1; }
+  if (o4 == GAMGI_PHYS_122) { offset[1] += 1; offset[2] += 2; }
   return;
   }
 
