@@ -56,7 +56,7 @@ static void static_link (gamgi_plane *plane,
 double *normal, gamgi_dlist *dlist);
 
 static void static_copy (gamgi_plane *plane,
-double *normal, gamgi_dlist *dlist);
+double *normal, gamgi_dlist *atoms);
 
 static gamgi_bool static_normal (gamgi_plane *plane, double *normal);
 
@@ -97,7 +97,7 @@ double reciprocal, double *transformation, double *orientation);
 void gamgi_phys_plane_point (gamgi_plane *plane,
 gamgi_cell *cell, double *point);
 
-void gamgi_phys_plane_normal (gamgi_plane *plane, double *normal);
+gamgi_bool gamgi_phys_plane_normal (gamgi_plane *plane, double *normal);
 
 void gamgi_phys_plane_default (double *p1, double *p2, 
 double *p3, gamgi_bool *inside, gamgi_darray *darray);
@@ -116,14 +116,16 @@ gamgi_atom *atom2, gamgi_atom *atom3);
 gamgi_bool gamgi_phys_plane_polygon (gamgi_atom *atom1,
 gamgi_atom *atom2, gamgi_atom *atom3);
 
-gamgi_dlist *gamgi_phys_plane_filter (gamgi_dlist *start);
-
 gamgi_dlist *gamgi_phys_plane_reorder (gamgi_dlist *start,
 gamgi_atom *atom1, gamgi_atom *atom2, gamgi_atom *atom3);
 
 void gamgi_phys_plane_atoms (gamgi_plane *plane, gamgi_atom *atom1,
 gamgi_atom *atom2, gamgi_atom *atom3, gamgi_dlist *dlist, gamgi_bool copy);
 
+void gamgi_phys_plane_polytope (int n_neighbours, gamgi_atom **neighbours,
+gamgi_enum autonomy, float red, float green, float blue, gamgi_object *parent,
+gamgi_atom *central);
+
 void gamgi_phys_plane_range (gamgi_plane *plane,
 gamgi_cell *cell, int start, int end);
 
